@@ -243,12 +243,7 @@ else
     # We want to suppress the output here so it looks nice
     # To see the output, remove the output redirection
     _msg "Fetching python (relenv)"
-    relenv fetch --python=$PY_VERSION
-    if [ -f "$RELENV_DIR/build/$PY_VERSION-x86_64-macos.tar.xz" ]; then
-        _success
-    else
-        _failure
-    fi
+    relenv fetch --python=$PY_VERSION && _success || _failure
 fi
 
 _msg "Extracting python environment"
@@ -262,6 +257,7 @@ fi
 #-------------------------------------------------------------------------------
 # Removing Unneeded Libraries from Python
 #-------------------------------------------------------------------------------
+PY_VERSION_MINOR=$($BLD_PY_BIN -c 'import sys; sys.stdout.write("{}.{}".format(*sys.version_info))')
 REMOVE=(
     "idlelib"
     "test"
@@ -269,16 +265,10 @@ REMOVE=(
     "turtledemo"
 )
 for i in "${REMOVE[@]}"; do
-    TEST_DIR="$BUILD_DIR/opt/salt/lib/python3.*/$i"
-    DIR=$(compgen -G "$TEST_DIR")
-    if [ -n "$DIR" ]; then
+    TEST_DIR="$BUILD_DIR/opt/salt/lib/python${PY_VERSION_MINOR}/$i"
+    if [ -d "$TEST_DIR" ]; then
         _msg "Removing $i directory"
-        rm -rf "$DIR"
-        if ! compgen -G "$TEST_DIR" > /dev/null; then
-            _success
-        else
-            _failure
-        fi
+        rm -rf "$TEST_DIR" && _success || _failure
     fi
 done
 
