@@ -2,10 +2,10 @@
 Salt module to manage Unix mounts and the fstab file
 """
 
+
 import logging
 import os
 import re
-from collections import OrderedDict
 
 import salt.utils.args
 import salt.utils.data
@@ -15,6 +15,7 @@ import salt.utils.path
 import salt.utils.platform
 import salt.utils.stringutils
 from salt.exceptions import CommandExecutionError, CommandNotFoundError
+from salt.utils.odict import OrderedDict
 
 # Set up logger
 log = logging.getLogger(__name__)
@@ -863,10 +864,7 @@ def set_fstab(
         criteria = entry.pick(match_on)
 
     except KeyError:
-
-        def filterFn(key):
-            return key not in _fstab_entry.fstab_keys
-
+        filterFn = lambda key: key not in _fstab_entry.fstab_keys
         invalid_keys = filter(filterFn, match_on)
 
         msg = f'Unrecognized keys in match_on: "{invalid_keys}"'
@@ -996,10 +994,7 @@ def set_vfstab(
         criteria = entry.pick(match_on)
 
     except KeyError:
-
-        def filterFn(key):
-            return key not in _vfstab_entry.vfstab_keys
-
+        filterFn = lambda key: key not in _vfstab_entry.vfstab_keys
         invalid_keys = filter(filterFn, match_on)
 
         msg = f'Unrecognized keys in match_on: "{invalid_keys}"'
@@ -1388,7 +1383,7 @@ def remount(name, device, mkmnt=False, fstype="", opts="defaults", user=None):
     return mount(name, device, mkmnt, fstype, opts, user=user)
 
 
-def umount(name, device=None, user=None, util="mount"):
+def umount(name, device=None, user=None, util="mount", lazy=False):
     """
     Attempt to unmount a device by specifying the directory it is mounted on
 
@@ -1418,10 +1413,14 @@ def umount(name, device=None, user=None, util="mount"):
     if name not in mnts:
         return f"{name} does not have anything mounted"
 
+    cmd = "umount"
+    if lazy:
+        cmd = f"{cmd} -l"
     if not device:
-        cmd = f"umount '{name}'"
+        cmd = f"{cmd} '{name}'"
     else:
-        cmd = f"umount '{device}'"
+        cmd = f"{cmd}'{device}'"
+
     out = __salt__["cmd.run_all"](cmd, runas=user, python_shell=False)
     if out["retcode"]:
         return out["stderr"]
@@ -1881,10 +1880,7 @@ def set_filesystems(
         criteria = entry_ip.pick(match_on)
 
     except KeyError:
-
-        def filterFn(key):
-            return key not in _FileSystemsEntry.compatibility_keys
-
+        filterFn = lambda key: key not in _FileSystemsEntry.compatibility_keys
         invalid_keys = filter(filterFn, match_on)
         raise CommandExecutionError(f'Unrecognized keys in match_on: "{invalid_keys}"')
 
@@ -1928,7 +1924,7 @@ def set_filesystems(
         except OSError:
             raise CommandExecutionError(f"File not writable {config}")
         except Exception as exc:
-            raise CommandExecutionError("set_filesystems error exception {exc}")
+            raise CommandExecutionError(f"set_filesystems error exception {exc}")
 
     return ret
 
@@ -1977,7 +1973,7 @@ def rm_filesystems(name, device, config="/etc/filesystems"):
         except OSError as exc:
             raise CommandExecutionError(f"Couldn't write to {config}: {exc}")
         except Exception as exc:
-            raise CommandExecutionError("rm_filesystems error exception {exc}")
+            raise CommandExecutionError(f"rm_filesystems error exception {exc}")
 
     return modified
 
