@@ -37,13 +37,20 @@ def __virtual__():
 
 def _convert_to_mb(size):
 
-    size = str(size)
-    unit = size[-1:].lower()
+    str_size = str(size).lower()
+    unit = str_size[-1:]
     if unit.isdigit():
         unit = "m"
+    elif unit == "b":
+        unit = str_size[-2:-1]
+        str_size = str_size[:-2]
     else:
-        size = size[:-1]
-    size = int(size)
+        str_size = str_size[:-1]
+
+    if str_size[-1:].isdigit():
+        size = int(str_size)
+    else:
+        raise salt.exceptions.ArgumentValueError(f"Size {size} is invalid.")
 
     if unit == "s":
         target_size = size / 2048
@@ -56,7 +63,7 @@ def _convert_to_mb(size):
     elif unit == "p":
         target_size = size * 1024 * 1024 * 1024
     else:
-        raise salt.exceptions.ArgumentValueError("Unit {} is invalid.".format(unit))
+        raise salt.exceptions.ArgumentValueError(f"Unit {unit} is invalid.")
     return target_size
 
 
@@ -74,19 +81,19 @@ def pv_present(name, **kwargs):
     ret = {"changes": {}, "comment": "", "name": name, "result": True}
 
     if __salt__["lvm.pvdisplay"](name, quiet=True):
-        ret["comment"] = "Physical Volume {} already present".format(name)
+        ret["comment"] = f"Physical Volume {name} already present"
     elif __opts__["test"]:
-        ret["comment"] = "Physical Volume {} is set to be created".format(name)
+        ret["comment"] = f"Physical Volume {name} is set to be created"
         ret["result"] = None
         return ret
     else:
         changes = __salt__["lvm.pvcreate"](name, **kwargs)
 
         if __salt__["lvm.pvdisplay"](name):
-            ret["comment"] = "Created Physical Volume {}".format(name)
+            ret["comment"] = f"Created Physical Volume {name}"
             ret["changes"]["created"] = changes
         else:
-            ret["comment"] = "Failed to create Physical Volume {}".format(name)
+            ret["comment"] = f"Failed to create Physical Volume {name}"
             ret["result"] = False
     return ret
 
@@ -101,19 +108,19 @@ def pv_absent(name):
     ret = {"changes": {}, "comment": "", "name": name, "result": True}
 
     if not __salt__["lvm.pvdisplay"](name, quiet=True):
-        ret["comment"] = "Physical Volume {} does not exist".format(name)
+        ret["comment"] = f"Physical Volume {name} does not exist"
     elif __opts__["test"]:
-        ret["comment"] = "Physical Volume {} is set to be removed".format(name)
+        ret["comment"] = f"Physical Volume {name} is set to be removed"
         ret["result"] = None
         return ret
     else:
         changes = __salt__["lvm.pvremove"](name)
 
         if __salt__["lvm.pvdisplay"](name, quiet=True):
-            ret["comment"] = "Failed to remove Physical Volume {}".format(name)
+            ret["comment"] = f"Failed to remove Physical Volume {name}"
             ret["result"] = False
         else:
-            ret["comment"] = "Removed Physical Volume {}".format(name)
+            ret["comment"] = f"Removed Physical Volume {name}"
             ret["changes"]["removed"] = changes
     return ret
 
@@ -137,23 +144,23 @@ def vg_present(name, devices=None, **kwargs):
         devices = devices.split(",")
 
     if __salt__["lvm.vgdisplay"](name, quiet=True):
-        ret["comment"] = "Volume Group {} already present".format(name)
+        ret["comment"] = f"Volume Group {name} already present"
         for device in devices:
             realdev = os.path.realpath(device)
             pvs = __salt__["lvm.pvdisplay"](realdev, real=True)
             if pvs and pvs.get(realdev, None):
                 if pvs[realdev]["Volume Group Name"] == name:
                     ret["comment"] = "{}\n{}".format(
-                        ret["comment"], "{} is part of Volume Group".format(device)
+                        ret["comment"], f"{device} is part of Volume Group"
                     )
                 elif pvs[realdev]["Volume Group Name"] in ["", "#orphans_lvm2"]:
                     __salt__["lvm.vgextend"](name, device)
                     pvs = __salt__["lvm.pvdisplay"](realdev, real=True)
                     if pvs[realdev]["Volume Group Name"] == name:
-                        ret["changes"].update({device: "added to {}".format(name)})
+                        ret["changes"].update({device: f"added to {name}"})
                     else:
                         ret["comment"] = "{}\n{}".format(
-                            ret["comment"], "{} could not be added".format(device)
+                            ret["comment"], f"{device} could not be added"
                         )
                         ret["result"] = False
                 else:
@@ -166,21 +173,21 @@ def vg_present(name, devices=None, **kwargs):
                     ret["result"] = False
             else:
                 ret["comment"] = "{}\n{}".format(
-                    ret["comment"], "pv {} is not present".format(device)
+                    ret["comment"], f"pv {device} is not present"
                 )
                 ret["result"] = False
     elif __opts__["test"]:
-        ret["comment"] = "Volume Group {} is set to be created".format(name)
+        ret["comment"] = f"Volume Group {name} is set to be created"
         ret["result"] = None
         return ret
     else:
         changes = __salt__["lvm.vgcreate"](name, devices, **kwargs)
 
         if __salt__["lvm.vgdisplay"](name):
-            ret["comment"] = "Created Volume Group {}".format(name)
+            ret["comment"] = f"Created Volume Group {name}"
             ret["changes"]["created"] = changes
         else:
-            ret["comment"] = "Failed to create Volume Group {}".format(name)
+            ret["comment"] = f"Failed to create Volume Group {name}"
             ret["result"] = False
     return ret
 
@@ -195,19 +202,19 @@ def vg_absent(name):
     ret = {"changes": {}, "comment": "", "name": name, "result": True}
 
     if not __salt__["lvm.vgdisplay"](name, quiet=True):
-        ret["comment"] = "Volume Group {} already absent".format(name)
+        ret["comment"] = f"Volume Group {name} already absent"
     elif __opts__["test"]:
-        ret["comment"] = "Volume Group {} is set to be removed".format(name)
+        ret["comment"] = f"Volume Group {name} is set to be removed"
         ret["result"] = None
         return ret
     else:
         changes = __salt__["lvm.vgremove"](name)
 
         if not __salt__["lvm.vgdisplay"](name, quiet=True):
-            ret["comment"] = "Removed Volume Group {}".format(name)
+            ret["comment"] = f"Removed Volume Group {name}"
             ret["changes"]["removed"] = changes
         else:
-            ret["comment"] = "Failed to remove Volume Group {}".format(name)
+            ret["comment"] = f"Failed to remove Volume Group {name}"
             ret["result"] = False
     return ret
 
@@ -223,7 +230,7 @@ def lv_present(
     thinpool=False,
     force=False,
     resizefs=False,
-    **kwargs
+    **kwargs,
 ):
     """
     Ensure that a Logical Volume is present, creating it if absent.
@@ -235,7 +242,9 @@ def lv_present(
         The name of the Volume Group on which the Logical Volume resides
 
     size
-        The size of the Logical Volume
+        The size of the Logical Volume in megabytes, or use a suffix
+        such as S, M, G, T, P for 512 byte sectors, megabytes, gigabytes
+        or terabytes respectively. The suffix is case insensitive.
 
     extents
         The number of logical extents allocated to the Logical Volume
@@ -252,7 +261,7 @@ def lv_present(
         Any supported options to lvcreate. See
         :mod:`linux_lvm <salt.modules.linux_lvm>` for more details.
 
-    .. versionadded:: to_complete
+    .. versionadded:: 2016.11.0
 
     thinvolume
         Logical Volume is thinly provisioned
@@ -265,7 +274,7 @@ def lv_present(
     force
         Assume yes to all prompts
 
-    .. versionadded:: 3002.0
+    .. versionadded:: 3002
 
     resizefs
         Use fsadm to resize the logical volume filesystem if needed
@@ -278,6 +287,9 @@ def lv_present(
         ret["result"] = False
         return ret
 
+    if size:
+        size_mb = _convert_to_mb(size)
+
     _snapshot = None
 
     if snapshot:
@@ -287,14 +299,14 @@ def lv_present(
     if thinvolume:
         lvpath = "/dev/{}/{}".format(vgname.split("/")[0], name)
     else:
-        lvpath = "/dev/{}/{}".format(vgname, name)
+        lvpath = f"/dev/{vgname}/{name}"
 
     lv_info = __salt__["lvm.lvdisplay"](lvpath, quiet=True)
     lv_info = lv_info.get(lvpath)
 
     if not lv_info:
         if __opts__["test"]:
-            ret["comment"] = "Logical Volume {} is set to be created".format(name)
+            ret["comment"] = f"Logical Volume {name} is set to be created"
             ret["result"] = None
             return ret
         else:
@@ -308,11 +320,11 @@ def lv_present(
                 thinvolume=thinvolume,
                 thinpool=thinpool,
                 force=force,
-                **kwargs
+                **kwargs,
             )
 
             if __salt__["lvm.lvdisplay"](lvpath):
-                ret["comment"] = "Created Logical Volume {}".format(name)
+                ret["comment"] = f"Created Logical Volume {name}"
                 ret["changes"]["created"] = changes
             else:
                 ret["comment"] = "Failed to create Logical Volume {}. Error: {}".format(
@@ -320,13 +332,12 @@ def lv_present(
                 )
                 ret["result"] = False
     else:
-        ret["comment"] = "Logical Volume {} already present".format(name)
+        ret["comment"] = f"Logical Volume {name} already present"
 
         if size or extents:
             old_extents = int(lv_info["Current Logical Extents Associated"])
             old_size_mb = _convert_to_mb(lv_info["Logical Volume Size"] + "s")
             if size:
-                size_mb = _convert_to_mb(size)
                 extents = old_extents
             else:
                 # ignore percentage "extents" if the logical volume already exists
@@ -375,7 +386,7 @@ def lv_present(
                     lv_info = __salt__["lvm.lvdisplay"](lvpath, quiet=True)[lvpath]
                     new_size_mb = _convert_to_mb(lv_info["Logical Volume Size"] + "s")
                     if new_size_mb != old_size_mb:
-                        ret["comment"] = "Resized Logical Volume {}".format(name)
+                        ret["comment"] = f"Resized Logical Volume {name}"
                         ret["changes"]["resized"] = changes
                     else:
                         ret[
@@ -399,20 +410,20 @@ def lv_absent(name, vgname=None):
     """
     ret = {"changes": {}, "comment": "", "name": name, "result": True}
 
-    lvpath = "/dev/{}/{}".format(vgname, name)
+    lvpath = f"/dev/{vgname}/{name}"
     if not __salt__["lvm.lvdisplay"](lvpath, quiet=True):
-        ret["comment"] = "Logical Volume {} already absent".format(name)
+        ret["comment"] = f"Logical Volume {name} already absent"
     elif __opts__["test"]:
-        ret["comment"] = "Logical Volume {} is set to be removed".format(name)
+        ret["comment"] = f"Logical Volume {name} is set to be removed"
         ret["result"] = None
         return ret
     else:
         changes = __salt__["lvm.lvremove"](name, vgname)
 
         if not __salt__["lvm.lvdisplay"](lvpath, quiet=True):
-            ret["comment"] = "Removed Logical Volume {}".format(name)
+            ret["comment"] = f"Removed Logical Volume {name}"
             ret["changes"]["removed"] = changes
         else:
-            ret["comment"] = "Failed to remove Logical Volume {}".format(name)
+            ret["comment"] = f"Failed to remove Logical Volume {name}"
             ret["result"] = False
     return ret
