@@ -180,7 +180,6 @@ according to the www policy.
         - require:
           - x509: /etc/pki/www.key
 """
-
 import base64
 import copy
 import datetime
@@ -390,7 +389,7 @@ def certificate_managed(
     if days_valid is None and not_after is None:
         try:
             salt.utils.versions.warn_until(
-                "Potassium",
+                3009,
                 "The default value for `days_valid` will change to 30. Please adapt your code accordingly.",
             )
             days_valid = 365
@@ -400,7 +399,7 @@ def certificate_managed(
     if days_remaining is None:
         try:
             salt.utils.versions.warn_until(
-                "Potassium",
+                3009,
                 "The default value for `days_remaining` will change to 7. Please adapt your code accordingly.",
             )
             days_remaining = 90
@@ -409,7 +408,7 @@ def certificate_managed(
 
     if "algorithm" in kwargs:
         salt.utils.versions.warn_until(
-            "Potassium",
+            3009,
             "`algorithm` has been renamed to `digest`. Please update your code.",
         )
         digest = kwargs.pop("algorithm")
@@ -434,9 +433,9 @@ def certificate_managed(
         file_managed_test = _file_managed(name, test=True, replace=False, **file_args)
         if file_managed_test["result"] is False:
             ret["result"] = False
-            ret["comment"] = (
-                "Problem while testing file.managed changes, see its output"
-            )
+            ret[
+                "comment"
+            ] = "Problem while testing file.managed changes, see its output"
             _add_sub_state_run(ret, file_managed_test)
             return ret
 
@@ -782,7 +781,7 @@ def crl_managed(
     if days_valid is None:
         try:
             salt.utils.versions.warn_until(
-                "Potassium",
+                3009,
                 "The default value for `days_valid` will change to 7. Please adapt your code accordingly.",
             )
             days_valid = 100
@@ -792,7 +791,7 @@ def crl_managed(
     if days_remaining is None:
         try:
             salt.utils.versions.warn_until(
-                "Potassium",
+                3009,
                 "The default value for `days_remaining` will change to 3. Please adapt your code accordingly.",
             )
             days_remaining = 30
@@ -804,14 +803,14 @@ def crl_managed(
         parsed = {}
         if len(rev) == 1 and isinstance(rev[next(iter(rev))], list):
             salt.utils.versions.warn_until(
-                "Potassium",
+                3009,
                 "Revoked certificates should be specified as a simple list of dicts.",
             )
             for val in rev[next(iter(rev))]:
                 parsed.update(val)
         if "reason" in (parsed or rev):
             salt.utils.versions.warn_until(
-                "Potassium",
+                3009,
                 "The `reason` parameter for revoked certificates should be specified in extensions:CRLReason.",
             )
             salt.utils.dictupdate.set_dict_key_value(
@@ -840,9 +839,9 @@ def crl_managed(
 
         if file_managed_test["result"] is False:
             ret["result"] = False
-            ret["comment"] = (
-                "Problem while testing file.managed changes, see its output"
-            )
+            ret[
+                "comment"
+            ] = "Problem while testing file.managed changes, see its output"
             _add_sub_state_run(ret, file_managed_test)
             return ret
 
@@ -1056,7 +1055,7 @@ def csr_managed(
     # Deprecation checks vs the old x509 module
     if "algorithm" in kwargs:
         salt.utils.versions.warn_until(
-            "Potassium",
+            3009,
             "`algorithm` has been renamed to `digest`. Please update your code.",
         )
         digest = kwargs.pop("algorithm")
@@ -1079,9 +1078,9 @@ def csr_managed(
 
         if file_managed_test["result"] is False:
             ret["result"] = False
-            ret["comment"] = (
-                "Problem while testing file.managed changes, see its output"
-            )
+            ret[
+                "comment"
+            ] = "Problem while testing file.managed changes, see its output"
             _add_sub_state_run(ret, file_managed_test)
             return ret
 
@@ -1323,7 +1322,7 @@ def private_key_managed(
     # Deprecation checks vs the old x509 module
     if "bits" in kwargs:
         salt.utils.versions.warn_until(
-            "Potassium",
+            3009,
             "`bits` has been renamed to `keysize`. Please update your code.",
         )
         keysize = kwargs.pop("bits")
@@ -1363,9 +1362,9 @@ def private_key_managed(
 
         if file_managed_test["result"] is False:
             ret["result"] = False
-            ret["comment"] = (
-                "Problem while testing file.managed changes, see its output"
-            )
+            ret[
+                "comment"
+            ] = "Problem while testing file.managed changes, see its output"
             _add_sub_state_run(ret, file_managed_test)
             return ret
 
@@ -1585,9 +1584,9 @@ def _file_managed(name, test=None, **kwargs):
 def _check_file_ret(fret, ret, current):
     if fret["result"] is False:
         ret["result"] = False
-        ret["comment"] = (
-            f"Could not {'create' if not current else 'update'} file, see file.managed output"
-        )
+        ret[
+            "comment"
+        ] = f"Could not {'create' if not current else 'update'} file, see file.managed output"
         ret["changes"] = {}
         return False
     return True
