@@ -1,14 +1,14 @@
-# -*- coding: utf-8 -*-
 """
 Utils for making various web calls. Primarily designed for REST, SOAP, webhooks
 and the like, but also useful for basic HTTP testing.
 
 .. versionadded:: 2015.5.0
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-import cgi
+import email.message
 import gzip
+import http.client
+import http.cookiejar
 import io
 import logging
 import os
@@ -16,14 +16,18 @@ import pprint
 import re
 import socket
 import ssl
+import urllib.error
+import urllib.parse
+import urllib.request
+import xml.etree.ElementTree as ET
 import zlib
 
+import tornado.httpclient
+import tornado.httputil
+import tornado.simple_httpclient
+from tornado.httpclient import HTTPClient
+
 import salt.config
-import salt.ext.six.moves.http_client
-import salt.ext.six.moves.http_cookiejar
-import salt.ext.six.moves.urllib.request as urllib_request
-import salt.ext.tornado.httputil
-import salt.ext.tornado.simple_httpclient
 import salt.loader
 import salt.syspaths
 import salt.utils.args
@@ -34,50 +38,32 @@ import salt.utils.msgpack
 import salt.utils.network
 import salt.utils.platform
 import salt.utils.stringutils
+import salt.utils.url
 import salt.utils.xmlutil as xml
 import salt.utils.yaml
 import salt.version
-from salt._compat import ElementTree as ET
-from salt.ext import six
-from salt.ext.six.moves import StringIO
-from salt.ext.six.moves.urllib.error import URLError
-from salt.ext.six.moves.urllib.parse import splitquery
-from salt.ext.six.moves.urllib.parse import urlencode as _urlencode
-from salt.ext.six.moves.urllib.parse import urlparse
-from salt.ext.tornado.httpclient import HTTPClient
 from salt.template import compile_template
 from salt.utils.decorators.jinja import jinja_filter
 
 try:
-    from ssl import CertificateError
-    from ssl import match_hostname
+    from ssl import CertificateError, match_hostname
 
     HAS_MATCHHOSTNAME = True
 except ImportError:
     # pylint: disable=no-name-in-module
     try:
-        from backports.ssl_match_hostname import CertificateError
-        from backports.ssl_match_hostname import match_hostname
+        from backports.ssl_match_hostname import CertificateError, match_hostname
 
         HAS_MATCHHOSTNAME = True
     except ImportError:
         try:
-            from salt.ext.ssl_match_hostname import CertificateError
-            from salt.ext.ssl_match_hostname import match_hostname
+            from salt.ext.ssl_match_hostname import CertificateError, match_hostname
 
             HAS_MATCHHOSTNAME = True
         except ImportError:
             HAS_MATCHHOSTNAME = False
     # pylint: enable=no-name-in-module
 
-
-try:
-    import salt.ext.tornado.curl_httpclient
-
-    HAS_CURL_HTTPCLIENT = True
-except ImportError:
-    HAS_CURL_HTTPCLIENT = False
-
 try:
     import requests
 
@@ -93,7 +79,7 @@ except ImportError:
     HAS_CERTIFI = False
 
 log = logging.getLogger(__name__)
-USERAGENT = "Salt/{0}".format(salt.version.__version__)
+USERAGENT = f"Salt/{salt.version.__version__}"
 
 
 def __decompressContent(coding, pgctnt):
@@ -128,6 +114,37 @@ def __decompressContent(coding, pgctnt):
     return pgctnt
 
 
+def _decode_result_text(result_text, backend, decode_body=None, result=None):
+    """
+    Decode only the result_text
+    """
+    if backend == "requests":
+        if not isinstance(result_text, str) and decode_body:
+            result_text = result_text.decode(result.encoding or "utf-8")
+    else:
+        if isinstance(result_text, bytes) and decode_body:
+            result_text = result_text.decode("utf-8")
+    return result_text
+
+
+def _decode_result(result_text, result_headers, backend, decode_body=None, result=None):
+    """
+    Decode the result_text and headers.
+    """
+    if "Content-Type" in result_headers:
+        msg = email.message.EmailMessage()
+        msg.add_header("Content-Type", result_headers["Content-Type"])
+        if msg.get_content_type().startswith("text/"):
+            content_charset = msg.get_content_charset()
+            if content_charset and not isinstance(result_text, str):
+                result_text = result_text.decode(content_charset)
+    result_text = _decode_result_text(
+        result_text, backend, decode_body=decode_body, result=result
+    )
+
+    return result_text, result_headers
+
+
 @jinja_filter("http_query")
 def query(
     url,
@@ -179,7 +196,7 @@ def query(
     formdata_fieldname=None,
     formdata_filename=None,
     decode_body=True,
-    **kwargs
+    **kwargs,
 ):
     """
     Query a resource, and decode the return data
@@ -201,6 +218,37 @@ def query(
     if not backend:
         backend = opts.get("backend", "tornado")
 
+    proxy_host = opts.get("proxy_host", None)
+    if proxy_host:
+        proxy_host = salt.utils.stringutils.to_str(proxy_host)
+    proxy_port = opts.get("proxy_port", None)
+    proxy_username = opts.get("proxy_username", None)
+    if proxy_username:
+        proxy_username = salt.utils.stringutils.to_str(proxy_username)
+    proxy_password = opts.get("proxy_password", None)
+    if proxy_password:
+        proxy_password = salt.utils.stringutils.to_str(proxy_password)
+    no_proxy = opts.get("no_proxy", [])
+
+    if urllib.parse.urlparse(url).hostname in no_proxy:
+        proxy_host = None
+        proxy_port = None
+        proxy_username = None
+        proxy_password = None
+
+    http_proxy_url = None
+    if proxy_host and proxy_port:
+        if backend != "requests":
+            log.debug("Switching to request backend due to the use of proxies.")
+            backend = "requests"
+
+        if proxy_username and proxy_password:
+            http_proxy_url = (
+                f"http://{proxy_username}:{proxy_password}@{proxy_host}:{proxy_port}"
+            )
+        else:
+            http_proxy_url = f"http://{proxy_host}:{proxy_port}"
+
     match = re.match(
         r"https?://((25[0-5]|2[0-4]\d|[01]?\d\d?)\.){3}(25[0-5]|2[0-4]\d|[01]?\d\d?)($|/)",
         url,
@@ -222,7 +270,7 @@ def query(
 
     # Some libraries don't support separation of url and GET parameters
     # Don't need a try/except block, since Salt depends on tornado
-    url_full = salt.ext.tornado.httputil.url_concat(url, params) if params else url
+    url_full = tornado.httputil.url_concat(url, params) if params else url
 
     if ca_bundle is None:
         ca_bundle = get_ca_bundle(opts)
@@ -304,7 +352,7 @@ def query(
             auth = (username, password)
 
     if agent == USERAGENT:
-        agent = "{0} http.query()".format(agent)
+        agent = f"{agent} http.query()"
     header_dict["User-agent"] = agent
 
     if backend == "requests":
@@ -314,6 +362,11 @@ def query(
         log.trace("Request Headers: %s", sess.headers)
         sess_cookies = sess.cookies
         sess.verify = verify_ssl
+        if http_proxy_url is not None:
+            sess.proxies = {
+                "http": http_proxy_url,
+                "https": http_proxy_url,
+            }
     elif backend == "urllib2":
         sess_cookies = None
     else:
@@ -322,11 +375,9 @@ def query(
 
     if cookies is not None:
         if cookie_format == "mozilla":
-            sess_cookies = salt.ext.six.moves.http_cookiejar.MozillaCookieJar(
-                cookie_jar
-            )
+            sess_cookies = http.cookiejar.MozillaCookieJar(cookie_jar)
         else:
-            sess_cookies = salt.ext.six.moves.http_cookiejar.LWPCookieJar(cookie_jar)
+            sess_cookies = http.cookiejar.LWPCookieJar(cookie_jar)
         if not os.path.isfile(cookie_jar):
             sess_cookies.save()
         sess_cookies.load()
@@ -349,7 +400,7 @@ def query(
 
         # Client-side cert handling
         if cert is not None:
-            if isinstance(cert, six.string_types):
+            if isinstance(cert, str):
                 if os.path.exists(cert):
                     req_kwargs["cert"] = cert
             elif isinstance(cert, list):
@@ -357,8 +408,7 @@ def query(
                     req_kwargs["cert"] = cert
             else:
                 log.error(
-                    "The client-side certificate path that"
-                    " was passed is not valid: %s",
+                    "The client-side certificate path that was passed is not valid: %s",
                     cert,
                 )
 
@@ -371,15 +421,15 @@ def query(
                 method,
                 url,
                 params=params,
-                files={formdata_fieldname: (formdata_filename, StringIO(data))},
-                **req_kwargs
+                files={formdata_fieldname: (formdata_filename, io.StringIO(data))},
+                **req_kwargs,
             )
         else:
             result = sess.request(method, url, params=params, data=data, **req_kwargs)
         result.raise_for_status()
         if stream is True:
             # fake a HTTP response header
-            header_callback("HTTP/1.0 {0} MESSAGE".format(result.status_code))
+            header_callback(f"HTTP/1.0 {result.status_code} MESSAGE")
             # fake streaming the content
             streaming_callback(result.content)
             return {
@@ -400,20 +450,20 @@ def query(
         result_headers = result.headers
         result_text = result.content
         result_cookies = result.cookies
-        body = result.content
-        if not isinstance(body, six.text_type) and decode_body:
-            body = body.decode(result.encoding or "utf-8")
-        ret["body"] = body
+        result_text = _decode_result_text(
+            result_text, backend, decode_body=decode_body, result=result
+        )
+        ret["body"] = result_text
     elif backend == "urllib2":
-        request = urllib_request.Request(url_full, data)
+        request = urllib.request.Request(url_full, data)
         handlers = [
-            urllib_request.HTTPHandler,
-            urllib_request.HTTPCookieProcessor(sess_cookies),
+            urllib.request.HTTPHandler,
+            urllib.request.HTTPCookieProcessor(sess_cookies),
         ]
 
         if url.startswith("https"):
             hostname = request.get_host()
-            handlers[0] = urllib_request.HTTPSHandler(1)
+            handlers[0] = urllib.request.HTTPSHandler(1)
             if not HAS_MATCHHOSTNAME:
                 log.warning(
                     "match_hostname() not available, SSL hostname checking "
@@ -439,7 +489,7 @@ def query(
                 except CertificateError as exc:
                     ret[
                         "error"
-                    ] = "The certificate was invalid. Error returned was: {0}".format(
+                    ] = "The certificate was invalid. Error returned was: {}".format(
                         pprint.pformat(exc)
                     )
                     return ret
@@ -447,7 +497,7 @@ def query(
                 # Client-side cert handling
                 if cert is not None:
                     cert_chain = None
-                    if isinstance(cert, six.string_types):
+                    if isinstance(cert, str):
                         if os.path.exists(cert):
                             cert_chain = cert
                     elif isinstance(cert, list):
@@ -464,7 +514,7 @@ def query(
                         # Python >= 2.7.9
                         context = ssl.SSLContext.load_cert_chain(*cert_chain)
                         handlers.append(
-                            urllib_request.HTTPSHandler(context=context)
+                            urllib.request.HTTPSHandler(context=context)
                         )  # pylint: disable=E1123
                     else:
                         # Python < 2.7.9
@@ -475,18 +525,16 @@ def query(
                         }
                         if len(cert_chain) > 1:
                             cert_kwargs["key_file"] = cert_chain[1]
-                        handlers[0] = salt.ext.six.moves.http_client.HTTPSConnection(
-                            **cert_kwargs
-                        )
+                        handlers[0] = http.client.HTTPSConnection(**cert_kwargs)
 
-        opener = urllib_request.build_opener(*handlers)
+        opener = urllib.request.build_opener(*handlers)
         for header in header_dict:
             request.add_header(header, header_dict[header])
         request.get_method = lambda: method
         try:
             result = opener.open(request)
-        except URLError as exc:
-            return {"Error": six.text_type(exc)}
+        except urllib.error.URLError as exc:
+            return {"Error": str(exc)}
         if stream is True or handle is True:
             return {
                 "handle": result,
@@ -496,18 +544,9 @@ def query(
         result_status_code = result.code
         result_headers = dict(result.info())
         result_text = result.read()
-        if "Content-Type" in result_headers:
-            res_content_type, res_params = cgi.parse_header(
-                result_headers["Content-Type"]
-            )
-            if (
-                res_content_type.startswith("text/")
-                and "charset" in res_params
-                and not isinstance(result_text, six.text_type)
-            ):
-                result_text = result_text.decode(res_params["charset"])
-        if six.PY3 and isinstance(result_text, bytes) and decode_body:
-            result_text = result_text.decode("utf-8")
+        result_text, result_headers = _decode_result(
+            result_text, result_headers, backend, decode_body=decode_body, result=result
+        )
         ret["body"] = result_text
     else:
         # Tornado
@@ -515,7 +554,7 @@ def query(
 
         # Client-side cert handling
         if cert is not None:
-            if isinstance(cert, six.string_types):
+            if isinstance(cert, str):
                 if os.path.exists(cert):
                     req_kwargs["client_cert"] = cert
             elif isinstance(cert, list):
@@ -524,13 +563,12 @@ def query(
                     req_kwargs["client_key"] = cert[1]
             else:
                 log.error(
-                    "The client-side certificate path that "
-                    "was passed is not valid: %s",
+                    "The client-side certificate path that was passed is not valid: %s",
                     cert,
                 )
 
         if isinstance(data, dict):
-            data = _urlencode(data)
+            data = urllib.parse.urlencode(data)
 
         if verify_ssl:
             req_kwargs["ca_certs"] = ca_bundle
@@ -547,49 +585,10 @@ def query(
             salt.config.DEFAULT_MINION_OPTS["http_request_timeout"],
         )
 
-        client_argspec = None
-
-        proxy_host = opts.get("proxy_host", None)
-        if proxy_host:
-            # tornado requires a str for proxy_host, cannot be a unicode str in py2
-            proxy_host = salt.utils.stringutils.to_str(proxy_host)
-        proxy_port = opts.get("proxy_port", None)
-        proxy_username = opts.get("proxy_username", None)
-        if proxy_username:
-            # tornado requires a str, cannot be unicode str in py2
-            proxy_username = salt.utils.stringutils.to_str(proxy_username)
-        proxy_password = opts.get("proxy_password", None)
-        if proxy_password:
-            # tornado requires a str, cannot be unicode str in py2
-            proxy_password = salt.utils.stringutils.to_str(proxy_password)
-        no_proxy = opts.get("no_proxy", [])
-
-        # Since tornado doesnt support no_proxy, we'll always hand it empty proxies or valid ones
-        # except we remove the valid ones if a url has a no_proxy hostname in it
-        if urlparse(url_full).hostname in no_proxy:
-            proxy_host = None
-            proxy_port = None
-
-        # We want to use curl_http if we have a proxy defined
-        if proxy_host and proxy_port:
-            if HAS_CURL_HTTPCLIENT is False:
-                ret["error"] = (
-                    "proxy_host and proxy_port has been set. This requires pycurl and tornado, "
-                    "but the libraries does not seem to be installed"
-                )
-                log.error(ret["error"])
-                return ret
-
-            salt.ext.tornado.httpclient.AsyncHTTPClient.configure(
-                "tornado.curl_httpclient.CurlAsyncHTTPClient"
-            )
-            client_argspec = salt.utils.args.get_function_argspec(
-                salt.ext.tornado.curl_httpclient.CurlAsyncHTTPClient.initialize
-            )
-        else:
-            client_argspec = salt.utils.args.get_function_argspec(
-                salt.ext.tornado.simple_httpclient.SimpleAsyncHTTPClient.initialize
-            )
+        tornado.httpclient.AsyncHTTPClient.configure(None)
+        client_argspec = salt.utils.args.get_function_argspec(
+            tornado.simple_httpclient.SimpleAsyncHTTPClient.initialize
+        )
 
         supports_max_body_size = "max_body_size" in client_argspec.args
 
@@ -606,10 +605,6 @@ def query(
                 "header_callback": header_callback,
                 "connect_timeout": connect_timeout,
                 "request_timeout": timeout,
-                "proxy_host": proxy_host,
-                "proxy_port": proxy_port,
-                "proxy_username": proxy_username,
-                "proxy_password": proxy_password,
                 "raise_error": raise_error,
                 "decompress_response": False,
             }
@@ -627,14 +622,20 @@ def query(
                 else HTTPClient()
             )
             result = download_client.fetch(url_full, **req_kwargs)
-        except salt.ext.tornado.httpclient.HTTPError as exc:
+        except tornado.httpclient.HTTPError as exc:
             ret["status"] = exc.code
-            ret["error"] = six.text_type(exc)
+            ret["error"] = str(exc)
+            ret["body"], _ = _decode_result(
+                exc.response.body,
+                exc.response.headers,
+                backend,
+                decode_body=decode_body,
+            )
             return ret
-        except (socket.herror, socket.error, socket.timeout, socket.gaierror) as exc:
+        except (socket.herror, OSError, socket.timeout, socket.gaierror) as exc:
             if status is True:
                 ret["status"] = 0
-            ret["error"] = six.text_type(exc)
+            ret["error"] = str(exc)
             log.debug("Cannot perform 'http.query': %s - %s", url_full, ret["error"])
             return ret
 
@@ -647,18 +648,9 @@ def query(
         result_status_code = result.code
         result_headers = result.headers
         result_text = result.body
-        if "Content-Type" in result_headers:
-            res_content_type, res_params = cgi.parse_header(
-                result_headers["Content-Type"]
-            )
-            if (
-                res_content_type.startswith("text/")
-                and "charset" in res_params
-                and not isinstance(result_text, six.text_type)
-            ):
-                result_text = result_text.decode(res_params["charset"])
-        if six.PY3 and isinstance(result_text, bytes) and decode_body:
-            result_text = result_text.decode("utf-8")
+        result_text, result_headers = _decode_result(
+            result_text, result_headers, backend, decode_body=decode_body, result=result
+        )
         ret["body"] = result_text
         if "Set-Cookie" in result_headers and cookies is not None:
             result_cookies = parse_cookie_header(result_headers["Set-Cookie"])
@@ -735,9 +727,10 @@ def query(
 
         valid_decodes = ("json", "xml", "yaml", "plain")
         if decode_type not in valid_decodes:
-            ret["error"] = (
-                "Invalid decode_type specified. "
-                "Valid decode types are: {0}".format(pprint.pformat(valid_decodes))
+            ret[
+                "error"
+            ] = "Invalid decode_type specified. Valid decode types are: {}".format(
+                pprint.pformat(valid_decodes)
             )
             log.error(ret["error"])
             return ret
@@ -815,7 +808,10 @@ def get_ca_bundle(opts=None):
 
 
 def update_ca_bundle(
-    target=None, source=None, opts=None, merge_files=None,
+    target=None,
+    source=None,
+    opts=None,
+    merge_files=None,
 ):
     """
     Attempt to update the CA bundle file from a URL
@@ -852,7 +848,7 @@ def update_ca_bundle(
     query(source, text=True, decode=False, headers=False, status=False, text_out=target)
 
     if merge_files is not None:
-        if isinstance(merge_files, six.string_types):
+        if isinstance(merge_files, str):
             merge_files = [merge_files]
 
         if not isinstance(merge_files, list):
@@ -870,7 +866,7 @@ def update_ca_bundle(
                 try:
                     with salt.utils.files.fopen(cert_file, "r") as fcf:
                         merge_content = "\n".join((merge_content, fcf.read()))
-                except IOError as exc:
+                except OSError as exc:
                     log.error(
                         "Reading from %s caused the following error: %s", cert_file, exc
                     )
@@ -881,7 +877,7 @@ def update_ca_bundle(
                 with salt.utils.files.fopen(target, "a") as tfp:
                     tfp.write("\n")
                     tfp.write(merge_content)
-            except IOError as exc:
+            except OSError as exc:
                 log.error("Writing to %s caused the following error: %s", target, exc)
 
 
@@ -902,10 +898,8 @@ def _render(template, render, renderer, template_dict, opts):
         )
         if salt.utils.stringio.is_readable(ret):
             ret = ret.read()
-        if six.text_type(ret).startswith("#!") and not six.text_type(ret).startswith(
-            "#!/"
-        ):
-            ret = six.text_type(ret).split("\n", 1)[1]
+        if str(ret).startswith("#!") and not str(ret).startswith("#!/"):
+            ret = str(ret).split("\n", 1)[1]
         return ret
     with salt.utils.files.fopen(template, "r") as fh_:
         return fh_.read()
@@ -926,6 +920,7 @@ def parse_cookie_header(header):
         "secure",
         "comment",
         "max-age",
+        "samesite",
     )
 
     # Split into cookie(s); handles headers with multiple cookies defined
@@ -944,7 +939,8 @@ def parse_cookie_header(header):
     value_set = False
     for morsel in morsels:
         parts = morsel.split("=")
-        if parts[0].lower() in attribs:
+        parts[0] = parts[0].lower()
+        if parts[0] in attribs:
             if parts[0] in cookie:
                 cookies.append(cookie)
                 cookie = {}
@@ -995,9 +991,7 @@ def parse_cookie_header(header):
 
         # cookielib.Cookie() requires an epoch
         if "expires" in cookie:
-            cookie["expires"] = salt.ext.six.moves.http_cookiejar.http2time(
-                cookie["expires"]
-            )
+            cookie["expires"] = http.cookiejar.http2time(cookie["expires"])
 
         # Fill in missing required fields
         for req in reqd:
@@ -1010,11 +1004,10 @@ def parse_cookie_header(header):
         if cookie["expires"] == "":
             cookie["expires"] = 0
 
-        if "httponly" in cookie:
-            del cookie["httponly"]
-        ret.append(
-            salt.ext.six.moves.http_cookiejar.Cookie(name=name, value=value, **cookie)
-        )
+        # Remove attribs that don't apply to Cookie objects
+        cookie.pop("httponly", None)
+        cookie.pop("samesite", None)
+        ret.append(http.cookiejar.Cookie(name=name, value=value, **cookie))
 
     return ret
 
@@ -1024,7 +1017,7 @@ def sanitize_url(url, hide_fields):
     Make sure no secret fields show up in logs
     """
     if isinstance(hide_fields, list):
-        url_comps = splitquery(url)
+        url_comps = urllib.parse.splitquery(url)
         log_url = url_comps[0]
         if len(url_comps) > 1:
             log_url += "?"
@@ -1040,7 +1033,7 @@ def sanitize_url(url, hide_fields):
             log_url += url_tmp
         return log_url.rstrip("&")
     else:
-        return six.text_type(url)
+        return str(url)
 
 
 def _sanitize_url_components(comp_list, field):
@@ -1049,12 +1042,12 @@ def _sanitize_url_components(comp_list, field):
     """
     if not comp_list:
         return ""
-    elif comp_list[0].startswith("{0}=".format(field)):
-        ret = "{0}=XXXXXXXXXX&".format(field)
+    elif comp_list[0].startswith(f"{field}="):
+        ret = f"{field}=XXXXXXXXXX&"
         comp_list.remove(comp_list[0])
         return ret + _sanitize_url_components(comp_list, field)
     else:
-        ret = "{0}&".format(comp_list[0])
+        ret = f"{comp_list[0]}&"
         comp_list.remove(comp_list[0])
         return ret + _sanitize_url_components(comp_list, field)
 
