@@ -56,7 +56,7 @@ class CMDModuleTest(ModuleCase):
         self.assertTrue(self.run_function("cmd.run", ["echo $SHELL"]))
         self.assertEqual(
             self.run_function(
-                "cmd.run", ["echo $SHELL", f"shell={shell}"], python_shell=True
+                "cmd.run", ["echo $SHELL", "shell={}".format(shell)], python_shell=True
             ).rstrip(),
             shell,
         )
@@ -78,18 +78,6 @@ class CMDModuleTest(ModuleCase):
             ),
             "four\nfive",
         )
-        self.assertEqual(
-            self.run_function(
-                "cmd.run", ["cat"], stdin="one\\ntwo", stdin_raw_newlines=False
-            ),
-            "one\ntwo",
-        )
-        self.assertEqual(
-            self.run_function(
-                "cmd.run", ["cat"], stdin="one\\ntwo", stdin_raw_newlines=True
-            ),
-            "one\\ntwo",
-        )
         self.assertEqual(
             self.run_function(
                 "cmd.run", ['echo "a=b" | sed -e s/=/:/g'], python_shell=True
@@ -120,7 +108,7 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(
             self.run_function(
                 "cmd.run_stderr",
-                ['echo "cheese" 1>&2', f"shell={shell}"],
+                ['echo "cheese" 1>&2', "shell={}".format(shell)],
                 python_shell=True,
             ).rstrip(),
             "cheese" if not salt.utils.platform.is_windows() else '"cheese"',
@@ -138,7 +126,7 @@ class CMDModuleTest(ModuleCase):
 
         ret = self.run_function(
             "cmd.run_all",
-            ['echo "cheese" 1>&2', f"shell={shell}"],
+            ['echo "cheese" 1>&2', "shell={}".format(shell)],
             python_shell=True,
         )
         self.assertTrue("pid" in ret)
@@ -206,7 +194,7 @@ class CMDModuleTest(ModuleCase):
             expected_stderr = "No such file or directory"
         ret = self.run_function(
             "cmd.run_all",
-            [f"{func} {random_file}"],
+            ["{} {}".format(func, random_file)],
             success_stderr=[expected_stderr],
             python_shell=True,
         )
@@ -225,7 +213,6 @@ class CMDModuleTest(ModuleCase):
         )
 
     @pytest.mark.slow_test
-    @pytest.mark.skip_on_windows
     def test_script(self):
         """
         cmd.script
@@ -236,7 +223,6 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(ret["stdout"], args)
 
     @pytest.mark.slow_test
-    @pytest.mark.skip_on_windows
     def test_script_query_string(self):
         """
         cmd.script
@@ -247,7 +233,6 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(ret["stdout"], args)
 
     @pytest.mark.slow_test
-    @pytest.mark.skip_on_windows
     def test_script_retcode(self):
         """
         cmd.script_retcode
@@ -257,7 +242,6 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(ret, 0)
 
     @pytest.mark.slow_test
-    @pytest.mark.skip_on_windows
     def test_script_cwd(self):
         """
         cmd.script with cwd
@@ -271,7 +255,6 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(ret["stdout"], args)
 
     @pytest.mark.slow_test
-    @pytest.mark.skip_on_windows
     def test_script_cwd_with_space(self):
         """
         cmd.script with cwd
@@ -411,7 +394,7 @@ class CMDModuleTest(ModuleCase):
         result = self.run_function(
             "cmd.run_all", [cmd], runas=RUNTIME_VARS.RUNNING_TESTS_USER
         )
-        errmsg = f"The command returned: {result}"
+        errmsg = "The command returned: {}".format(result)
         self.assertEqual(result["retcode"], 0, errmsg)
         self.assertEqual(result["stdout"], expected_result, errmsg)
 
@@ -520,9 +503,9 @@ class CMDModuleTest(ModuleCase):
         """
         with self._ensure_user_exists(self.runas_usr):
             out = self.run_function(
-                "cmd.run", ["env"], runas=self.runas_usr, cwd="/tmp"
+                "cmd.run", ["env"], runas=self.runas_usr
             ).splitlines()
-        self.assertIn(f"USER={self.runas_usr}", out)
+        self.assertIn("USER={}".format(self.runas_usr), out)
 
     @pytest.mark.skip_if_binaries_missing("sleep", reason="sleep cmd not installed")
     def test_timeout(self):
@@ -613,3 +596,39 @@ class CMDModuleTest(ModuleCase):
         ).splitlines()
         self.assertIn("abc=123", out)
         self.assertIn("ABC=456", out)
+
+    @pytest.mark.slow_test
+    @pytest.mark.skip_unless_on_windows(reason="Minion is not Windows")
+    def test_windows_powershell_script_args(self):
+        """
+        Ensure that powershell processes inline script in args
+        """
+        val = "i like cheese"
+        args = (
+            '-SecureString (ConvertTo-SecureString -String "{}" -AsPlainText -Force)'
+            " -ErrorAction Stop".format(val)
+        )
+        script = "salt://issue-56195/test.ps1"
+        ret = self.run_function(
+            "cmd.script", [script], args=args, shell="powershell", saltenv="base"
+        )
+        self.assertEqual(ret["stdout"], val)
+
+    @pytest.mark.slow_test
+    @pytest.mark.skip_unless_on_windows(reason="Minion is not Windows")
+    @pytest.mark.skip_if_binaries_missing("pwsh")
+    def test_windows_powershell_script_args_pwsh(self):
+        """
+        Ensure that powershell processes inline script in args with powershell
+        core
+        """
+        val = "i like cheese"
+        args = (
+            '-SecureString (ConvertTo-SecureString -String "{}" -AsPlainText -Force)'
+            " -ErrorAction Stop".format(val)
+        )
+        script = "salt://issue-56195/test.ps1"
+        ret = self.run_function(
+            "cmd.script", [script], args=args, shell="pwsh", saltenv="base"
+        )
+        self.assertEqual(ret["stdout"], val)
