@@ -231,15 +231,12 @@ class CPModuleTest(ModuleCase):
         """
         cp.get_url with https:// source given
         """
-        self.run_function(
-            "cp.get_url",
-            ["https://packages.broadcom.com/artifactory/saltproject-generic/", tgt],
-        )
+        self.run_function("cp.get_url", ["https://repo.saltproject.io/index.html", tgt])
         with salt.utils.files.fopen(tgt, "r") as instructions:
             data = salt.utils.stringutils.to_unicode(instructions.read())
-        self.assertIn("Index of saltproject", data)
-        self.assertIn("onedir", data)
-        self.assertIn("Artifactory Online Server", data)
+        self.assertIn("Salt Project", data)
+        self.assertIn("Package", data)
+        self.assertIn("Repo", data)
         self.assertNotIn("AYBABTU", data)
 
     @pytest.mark.slow_test
@@ -248,15 +245,14 @@ class CPModuleTest(ModuleCase):
         cp.get_url with https:// source given and destination omitted.
         """
         ret = self.run_function(
-            "cp.get_url",
-            ["https://packages.broadcom.com/artifactory/saltproject-generic/"],
+            "cp.get_url", ["https://repo.saltproject.io/index.html"]
         )
 
         with salt.utils.files.fopen(ret, "r") as instructions:
             data = salt.utils.stringutils.to_unicode(instructions.read())
-        self.assertIn("Index of saltproject", data)
-        self.assertIn("onedir", data)
-        self.assertIn("Artifactory Online Server", data)
+        self.assertIn("Salt Project", data)
+        self.assertIn("Package", data)
+        self.assertIn("Repo", data)
         self.assertNotIn("AYBABTU", data)
 
     @pytest.mark.slow_test
@@ -270,19 +266,16 @@ class CPModuleTest(ModuleCase):
         tgt = None
         while time.time() - start <= timeout:
             ret = self.run_function(
-                "cp.get_url",
-                ["https://packages.broadcom.com/artifactory/saltproject-generic/", tgt],
+                "cp.get_url", ["https://repo.saltproject.io/index.html", tgt]
             )
             if ret.find("HTTP 599") == -1:
                 break
             time.sleep(sleep)
         if ret.find("HTTP 599") != -1:
-            raise Exception(
-                "https://packages.broadcom.com/artifactory/saltproject-generic/ returned 599 error"
-            )
-        self.assertIn("Index of saltproject", ret)
-        self.assertIn("onedir", ret)
-        self.assertIn("Artifactory Online Server", ret)
+            raise Exception("https://repo.saltproject.io/index.html returned 599 error")
+        self.assertIn("Salt Project", ret)
+        self.assertIn("Package", ret)
+        self.assertIn("Repo", ret)
         self.assertNotIn("AYBABTU", ret)
 
     @pytest.mark.slow_test
@@ -351,11 +344,11 @@ class CPModuleTest(ModuleCase):
         """
         cp.get_file_str with https:// source given
         """
-        src = "https://packages.broadcom.com/artifactory/saltproject-generic/"
+        src = "https://repo.saltproject.io/index.html"
         ret = self.run_function("cp.get_file_str", [src])
-        self.assertIn("Index of saltproject", ret)
-        self.assertIn("onedir", ret)
-        self.assertIn("Artifactory Online Server", ret)
+        self.assertIn("Salt Project", ret)
+        self.assertIn("Package", ret)
+        self.assertIn("Repo", ret)
         self.assertNotIn("AYBABTU", ret)
 
     @pytest.mark.slow_test
@@ -602,17 +595,18 @@ class CPModuleTest(ModuleCase):
     @pytest.mark.slow_test
     def test_push(self):
         log_to_xfer = os.path.join(RUNTIME_VARS.TMP, uuid.uuid4().hex)
-        open(  # pylint: disable=resource-leakage
-            log_to_xfer, "w", encoding="utf-8"
-        ).close()
+        open(log_to_xfer, "w").close()  # pylint: disable=resource-leakage
         try:
             self.run_function("cp.push", [log_to_xfer])
             tgt_cache_file = os.path.join(
-                RUNTIME_VARS.RUNTIME_CONFIGS["master"]["cachedir"],
+                RUNTIME_VARS.TMP,
+                "master-minion-root",
+                "cache",
                 "minions",
                 "minion",
                 "files",
-                os.path.splitdrive(os.path.normpath(log_to_xfer.lstrip(os.sep)))[1],
+                RUNTIME_VARS.TMP,
+                log_to_xfer,
             )
             self.assertTrue(
                 os.path.isfile(tgt_cache_file), "File was not cached on the master"
