@@ -11,17 +11,6 @@ from saltfactories.utils.tempfiles import temp_file
 from tests.support.case import SSHCase
 from tests.support.runtests import RUNTIME_VARS
 
-pytestmark = [
-    pytest.mark.skipif(
-        "grains['osfinger'] == 'Fedora Linux-39'",
-        reason="Fedora 39 ships with Python 3.12. Test can't run with system Python on 3.12",
-        # Actually, the problem is that the tornado we ship is not prepared for Python 3.12,
-        # and it imports `ssl` and checks if the `match_hostname` function is defined, which
-        # has been deprecated since Python 3.7, so, the logic goes into trying to import
-        # backports.ssl-match-hostname which is not installed on the system.
-    )
-]
-
 SSH_SLS = "ssh_state_tests"
 SSH_SLS_FILE = "/tmp/salt_test_file"
 
