@@ -50,4 +50,4 @@ class HostTest(ModuleCase, SaltReturnAssertsMixin):
         self.assertSaltTrueReturn(ret)
         with salt.utils.files.fopen(self.hosts_file) as fp_:
             output = salt.utils.stringutils.to_unicode(fp_.read())
-            self.assertIn(f"{ip}\t\t{name}", output)
+            self.assertIn("{}\t\t{}".format(ip, name), output)
