@@ -3,7 +3,6 @@
 """
 
 import logging
-import os
 import random
 
 import pytest
@@ -20,6 +19,7 @@ pytestmark = [
         reason="Deltaproxy minions do not currently work on spawning platforms.",
     ),
     pytest.mark.core_test,
+    pytest.mark.timeout_unless_on_windows(320),
 ]
 
 
@@ -61,17 +61,6 @@ def proxy_minion_id(salt_master):
         pytest.helpers.remove_stale_minion_key(salt_master, _proxy_minion_id)
 
 
-def clear_proxy_minions(salt_master, proxy_minion_id):
-    for proxy in [proxy_minion_id, "dummy_proxy_one", "dummy_proxy_two"]:
-        pytest.helpers.remove_stale_minion_key(salt_master, proxy)
-
-        cachefile = os.path.join(
-            salt_master.config["cachedir"], "{}.cache".format(proxy)
-        )
-        if os.path.exists(cachefile):
-            os.unlink(cachefile)
-
-
 # Hangs on Windows. You can add a timeout to the proxy.run command, but then
 # it just times out.
 @pytest.mark.skip_on_windows(reason=PRE_PYTEST_SKIP_REASON)
@@ -204,7 +193,6 @@ def test_exit_status_correct_usage_large_number_of_minions(
 
             with factory.started():
                 assert factory.is_running()
-
                 # Let's issue a ping the control proxy
                 ret = salt_cli.run("test.ping", minion_tgt=proxy_minion_id)
                 assert ret.returncode == 0
