@@ -56,7 +56,7 @@ class Network:
         return ipaddress.ip_network(self.subnet)
 
     @_rand_indexes.default
-    def __rand_indexes(self):  # pylint: disable=unused-private-member
+    def __rand_indexes(self):
         return random.sample(
             range(2, self.net.num_addresses - 1), self.net.num_addresses - 3
         )
@@ -71,14 +71,13 @@ class Network:
 
     @staticmethod
     def arg_map(arg_name):
-        if arg_name == "ipv4_address":
-            return "IPv4Address"
-        if arg_name == "ipv6_address":
-            return "IPv6Address"
-        if arg_name == "links":
-            return "Links"
-        if arg_name == "aliases":
-            return "Aliases"
+        nwmap = {
+            "ipv4_address": "IPv4Address",
+            "ipv6_address": "IPv6Address",
+            "links": "Links",
+            "aliases": "Aliases",
+        }
+        return nwmap[arg_name]
 
     @property
     def compressed_subnet(self):
@@ -170,10 +169,7 @@ def docker_container(states):
 
 
 @pytest.fixture(scope="module")
-def image(grains, tmp_path_factory):
-    if grains["os"] == "VMware Photon OS" and grains["osmajorrelease"] == 5:
-        pytest.skip(f"Temporary skip on {grains['osfinger']}")
-
+def image(tmp_path_factory):
     if not salt.utils.path.which("docker"):
         # Somehow the above skip_if_binaries_missing marker for docker
         # only get's evaluated after this fixture?!?
