@@ -4,7 +4,6 @@ tests for pkg state
 
 import logging
 import os
-import subprocess
 import time
 
 import pytest
@@ -20,17 +19,12 @@ pytestmark = [
     pytest.mark.slow_test,
     pytest.mark.skip_if_not_root,
     pytest.mark.destructive_test,
-    pytest.mark.windows_whitelisted,
     pytest.mark.timeout_unless_on_windows(240),
 ]
 
 
 @pytest.fixture(scope="module", autouse=True)
 def refresh_db(grains, modules):
-
-    if salt.utils.platform.is_windows():
-        modules.winrepo.update_git_repos()
-
     modules.pkg.refresh_db()
 
     # If this is Arch Linux, check if pacman is in use by another process
@@ -44,21 +38,11 @@ def refresh_db(grains, modules):
             pytest.fail("Package database locked after 60 seconds, bailing out")
 
 
-@pytest.fixture(scope="module", autouse=True)
-def refresh_keys(grains, modules):
-    if grains["os_family"] == "Arch":
-        # We should be running this periodically when building new test runner
-        # images, otherwise this could take several minutes to complete.
-        proc = subprocess.run(["pacman-key", "--refresh-keys"], check=False)
-        if proc.returncode != 0:
-            pytest.fail("pacman-key --refresh-keys command failed.")
-
-
 @pytest.fixture
 def PKG_TARGETS(grains):
     _PKG_TARGETS = ["figlet", "sl"]
     if grains["os"] == "Windows":
-        _PKG_TARGETS = ["npp_x64", "winrar"]
+        _PKG_TARGETS = ["vlc", "putty"]
     elif grains["os"] == "Amazon":
         if grains["osfinger"] == "Amazon Linux-2023":
             _PKG_TARGETS = ["lynx", "gnuplot-minimal"]
@@ -67,11 +51,11 @@ def PKG_TARGETS(grains):
     elif grains["os_family"] == "RedHat":
         if grains["os"] == "VMware Photon OS":
             if grains["osmajorrelease"] >= 5:
-                _PKG_TARGETS = ["ctags", "zsh"]
+                _PKG_TARGETS = ["wget", "zsh"]
             else:
-                _PKG_TARGETS = ["ctags", "zsh-html"]
+                _PKG_TARGETS = ["wget", "zsh-html"]
         elif (
-            grains["os"] in ("CentOS Stream", "Rocky", "AlmaLinux")
+            grains["os"] in ("CentOS Stream", "AlmaLinux")
             and grains["osmajorrelease"] == 9
         ):
             _PKG_TARGETS = ["units", "zsh"]
@@ -113,12 +97,7 @@ def PKG_32_TARGETS(grains):
     _PKG_32_TARGETS = []
     if grains["os_family"] == "RedHat" and grains["oscodename"] != "Photon":
         if grains["os"] == "CentOS":
-            if grains["osmajorrelease"] == 5:
-                _PKG_32_TARGETS = ["xz-devel.i386"]
-            else:
-                _PKG_32_TARGETS.append("xz-devel.i686")
-    elif grains["os"] == "Windows":
-        _PKG_32_TARGETS = ["npp", "putty"]
+            _PKG_32_TARGETS.append("xz-devel.i686")
     if not _PKG_32_TARGETS:
         pytest.skip("No 32 bit packages have been specified for testing")
     return _PKG_32_TARGETS
@@ -128,11 +107,7 @@ def PKG_32_TARGETS(grains):
 def PKG_DOT_TARGETS(grains):
     _PKG_DOT_TARGETS = []
     if grains["os_family"] == "RedHat" and grains["oscodename"] != "Photon":
-        if grains["osmajorrelease"] == 5:
-            _PKG_DOT_TARGETS = ["python-migrate0.5"]
-        elif grains["osmajorrelease"] == 6:
-            _PKG_DOT_TARGETS = ["tomcat6-el-2.1-api"]
-        elif grains["osmajorrelease"] == 7:
+        if grains["osmajorrelease"] == 7:
             _PKG_DOT_TARGETS = ["tomcat-el-2.2-api"]
         elif grains["osmajorrelease"] == 8:
             _PKG_DOT_TARGETS = ["aspnetcore-runtime-6.0"]
@@ -212,23 +187,6 @@ def latest_version(ctx, modules):
     return run_command
 
 
-@pytest.fixture(scope="function")
-def install_7zip(modules):
-    try:
-        modules.pkg.install(name="7zip", version="22.01.00.0")
-        modules.pkg.install(name="7zip", version="19.00.00.0")
-        versions = modules.pkg.version("7zip")
-        assert "19.00.00.0" in versions
-        assert "22.01.00.0" in versions
-        yield
-    finally:
-        modules.pkg.remove(name="7zip", version="19.00.00.0")
-        modules.pkg.remove(name="7zip", version="22.01.00.0")
-        versions = modules.pkg.version("7zip")
-        assert "19.00.00.0" not in versions
-        assert "22.01.00.0" not in versions
-
-
 @pytest.mark.requires_salt_modules("pkg.version")
 @pytest.mark.requires_salt_states("pkg.installed", "pkg.removed")
 @pytest.mark.slow_test
@@ -273,13 +231,10 @@ def test_pkg_002_installed_with_version(PKG_TARGETS, states, latest_version):
 
 @pytest.mark.requires_salt_states("pkg.installed", "pkg.removed")
 @pytest.mark.slow_test
-def test_pkg_003_installed_multipkg(caplog, PKG_TARGETS, modules, states, grains):
+def test_pkg_003_installed_multipkg(PKG_TARGETS, modules, states):
     """
     This is a destructive test as it installs and then removes two packages
     """
-    if grains["os_family"] == "Arch":
-        pytest.skip("Arch needs refresh_db logic added to golden image")
-
     version = modules.pkg.version(*PKG_TARGETS)
 
     # If this assert fails, we need to find new targets, this test needs to
@@ -292,8 +247,6 @@ def test_pkg_003_installed_multipkg(caplog, PKG_TARGETS, modules, states, grains
     try:
         ret = states.pkg.installed(name=None, pkgs=PKG_TARGETS, refresh=False)
         assert ret.result is True
-        if not salt.utils.platform.is_windows():
-            assert "WARNING" not in caplog.text
     finally:
         ret = states.pkg.removed(name=None, pkgs=PKG_TARGETS)
         assert ret.result is True
@@ -302,14 +255,10 @@ def test_pkg_003_installed_multipkg(caplog, PKG_TARGETS, modules, states, grains
 @pytest.mark.usefixtures("VERSION_SPEC_SUPPORTED")
 @pytest.mark.requires_salt_states("pkg.installed", "pkg.removed")
 @pytest.mark.slow_test
-def test_pkg_004_installed_multipkg_with_version(
-    PKG_TARGETS, latest_version, states, grains
-):
+def test_pkg_004_installed_multipkg_with_version(PKG_TARGETS, latest_version, states):
     """
     This is a destructive test as it installs and then removes two packages
     """
-    if grains["os_family"] == "Arch":
-        pytest.skip("Arch needs refresh_db logic added to golden image")
     version = latest_version(PKG_TARGETS[0])
 
     # If this assert fails, we need to find new targets, this test needs to
@@ -558,7 +507,7 @@ def test_pkg_012_installed_with_wildcard_version(PKG_TARGETS, states, modules):
     )
 
     expected_comment = (
-        "All specified packages are already installed and are at the desired version"
+        "All specified packages are already installed and are at the " "desired version"
     )
     assert ret.result is True
     assert ret.raw[next(iter(ret.raw))]["comment"] == expected_comment
@@ -918,7 +867,6 @@ def test_pkg_cap_003_installed_multipkg_with_version(
     latest_version,
     modules,
     states,
-    grains,
 ):
     """
     This is a destructive test as it installs and then removes two packages
@@ -1116,17 +1064,3 @@ def test_pkg_purged_with_removed_pkg(grains, PKG_TARGETS, states, modules):
         "installed": {},
         "removed": {target: {"new": "", "old": version}},
     }
-
-
-@pytest.mark.skip_unless_on_windows()
-def test_pkg_removed_with_version_multiple(install_7zip, modules, states):
-    """
-    This tests removing a specific version of a package when multiple versions
-    are installed. This is specific to Windows. The only version I could find
-    that allowed multiple installs of differing versions was 7zip, so we'll use
-    that.
-    """
-    ret = states.pkg.removed(name="7zip", version="19.00.00.0")
-    assert ret.result is True
-    current = modules.pkg.version("7zip")
-    assert "22.01.00.0" in current
