@@ -1,20 +1,16 @@
+import asyncio
 import logging
 
 import pytest
+import tornado.gen
+import tornado.iostream
+import tornado.tcpserver
 
-import salt.ext.tornado.gen
-import salt.ext.tornado.iostream
-import salt.ext.tornado.tcpserver
 import salt.transport.tcp
 import salt.utils.msgpack
 
 log = logging.getLogger(__name__)
 
-pytestmark = [
-    pytest.mark.windows_whitelisted,
-    pytest.mark.core_test,
-]
-
 
 @pytest.fixture
 def config():
@@ -26,23 +22,29 @@ def config():
 
 @pytest.fixture
 def server(config):
-    class TestServer(salt.ext.tornado.tcpserver.TCPServer):
+    class TestServer(tornado.tcpserver.TCPServer):
         send = []
         disconnect = False
 
-        async def handle_stream(  # pylint: disable=invalid-overridden-method
-            self, stream, address
-        ):
-            while self.disconnect is False:
-                for msg in self.send[:]:
-                    msg = self.send.pop(0)
-                    try:
-                        await stream.write(msg)
-                    except salt.ext.tornado.iostream.StreamClosedError:
-                        break
-                else:
-                    await salt.ext.tornado.gen.sleep(1)
-            stream.close()
+        async def handle_stream(self, stream, address):
+            try:
+                log.info("Got stream %r", self.disconnect)
+                while self.disconnect is False:
+                    for msg in self.send[:]:
+                        msg = self.send.pop(0)
+                        try:
+                            log.info("Write %r", msg)
+                            await stream.write(msg)
+                        except tornado.iostream.StreamClosedError:
+                            log.error("Stream Closed Error From Test Server")
+                            break
+                    else:
+                        log.info("Sleep")
+                        await asyncio.sleep(1)
+                log.info("Close stream")
+            finally:
+                stream.close()
+                log.info("After close stream")
 
     server = TestServer()
     try:
@@ -54,14 +56,16 @@ def server(config):
 
 @pytest.fixture
 def client(io_loop, config):
-    client = salt.transport.tcp.TCPPubClient(config.copy(), io_loop)
+    client = salt.transport.tcp.PublishClient(
+        config.copy(), io_loop, host=config["master_ip"], port=config["publish_port"]
+    )
     try:
         yield client
     finally:
         client.close()
 
 
-async def test_message_client_reconnect(io_loop, config, client, server):
+async def test_message_client_reconnect(config, client, server):
     """
     Verify that the tcp MessageClient class re-sets it's unpacker after a
     stream disconnect.
@@ -72,11 +76,10 @@ async def test_message_client_reconnect(io_loop, config, client, server):
 
     received = []
 
-    def handler(msg):
+    async def handler(msg):
         received.append(msg)
 
     client.on_recv(handler)
-
     # Prepare two packed messages
     msg = salt.utils.msgpack.dumps({"test": "test1"})
     pmsg = salt.utils.msgpack.dumps({"head": {}, "body": msg})
@@ -85,18 +88,24 @@ async def test_message_client_reconnect(io_loop, config, client, server):
 
     # Send one full and one partial msg to the client.
     partial = pmsg[:40]
+    log.info("Send partial %r", partial)
     server.send.append(partial)
 
     while not received:
-        await salt.ext.tornado.gen.sleep(1)
+        log.info("wait received")
+        await asyncio.sleep(1)
+    log.info("assert received")
     assert received == [msg]
+    # log.info("sleep")
+    # await asyncio.sleep(1)
 
     # The message client has unpacked one msg and there is a partial msg left in
     # the unpacker. Closing the stream now leaves the unpacker in a bad state
     # since the rest of the partil message will never be received.
     server.disconnect = True
-    await salt.ext.tornado.gen.sleep(1)
+    await asyncio.sleep(1)
     server.disconnect = False
+    await asyncio.sleep(1)
     received = []
 
     # Prior to the fix for #60831, the unpacker would be left in a broken state
@@ -104,5 +113,12 @@ async def test_message_client_reconnect(io_loop, config, client, server):
     # rest of this test would fail.
     server.send.append(pmsg)
     while not received:
-        await salt.ext.tornado.gen.sleep(1)
+        await tornado.gen.sleep(1)
     assert received == [msg, msg]
+    server.disconnect = True
+
+    # Close the client
+    client.close()
+
+    # Provide time for the on_recv task to complete
+    await asyncio.sleep(0.3)
