@@ -1,7 +1,9 @@
-import multiprocessing
+import os
+import threading
 import time
 
-import salt.ext.tornado.gen
+import tornado.gen
+
 import salt.transport.tcp
 
 
@@ -15,43 +17,50 @@ async def test_pub_channel(master_opts, minion_opts, io_loop):
     master_opts["transport"] = "tcp"
     minion_opts.update(master_ip="127.0.0.1", transport="tcp")
 
-    server = salt.transport.tcp.TCPPublishServer(master_opts)
+    server = salt.transport.tcp.TCPPublishServer(
+        master_opts,
+        pub_host="127.0.0.1",
+        pub_port=master_opts["publish_port"],
+        pull_path=os.path.join(master_opts["sock_dir"], "publish_pull.ipc"),
+    )
 
-    client = salt.transport.tcp.TCPPubClient(minion_opts, io_loop)
+    client = salt.transport.tcp.TCPPubClient(
+        minion_opts,
+        io_loop,
+        host="127.0.0.1",
+        port=master_opts["publish_port"],
+    )
 
     payloads = []
 
     publishes = []
 
-    def publish_payload(payload, callback):
-        server.publish_payload(payload)
+    async def publish_payload(payload, callback):
+        await server.publish_payload(payload)
         payloads.append(payload)
 
-    def on_recv(message):
+    async def on_recv(message):
         publishes.append(message)
 
-    proc = multiprocessing.Process(
-        target=server.publish_daemon,
-        args=(publish_payload, presence_callback, remove_presence_callback),
+    io_loop.add_callback(
+        server.publisher, publish_payload, presence_callback, remove_presence_callback
     )
-    proc.start()
 
     # Wait for socket to bind.
-    time.sleep(3)
+    await tornado.gen.sleep(3)
 
     await client.connect(master_opts["publish_port"])
     client.on_recv(on_recv)
 
-    server.publish({"meh": "bah"})
+    await server.publish({"meh": "bah"})
 
     start = time.monotonic()
     try:
         while not publishes:
-            await salt.ext.tornado.gen.sleep(0.3)
+            await tornado.gen.sleep(0.3)
             if time.monotonic() - start > 30:
                 assert False, "Message not published after 30 seconds"
     finally:
-        client.close()
         server.close()
-        proc.terminate()
-        proc.join()
+        server.pub_server.close()
+        client.close()
