@@ -1,6 +1,8 @@
 import ast
+import copy
 import os
 import re
+import shutil
 import textwrap
 
 import pytest
@@ -73,15 +75,6 @@ def test_remove_key(salt_master, salt_key_cli):
             os.unlink(key)
 
 
-def test_remove_all_keys_with_arg(salt_key_cli):
-    """
-    test salt-key -D usage with args
-    """
-    # Remove Key
-    ret = salt_key_cli.run("-D", "junk")
-    assert "Delete all takes no arguments" in ret.stderr
-
-
 @pytest.mark.skip_if_not_root
 @pytest.mark.destructive_test
 @pytest.mark.skip_on_windows(reason="PAM is not supported on Windows")
@@ -167,6 +160,49 @@ def test_list_all(salt_key_cli, salt_minion, salt_sub_minion):
     assert ret.data == expected
 
 
+def test_list_all_no_check_files(
+    salt_key_cli, salt_minion, salt_sub_minion, tmp_path, salt_master
+):
+    """
+    test salt-key -L
+    """
+    config_dir = tmp_path / "key_no_check_files"
+    config_dir.mkdir()
+    pki_dir = config_dir / "pki_dir"
+    shutil.copytree(salt_master.config["pki_dir"], str(pki_dir))
+    with pytest.helpers.change_cwd(str(config_dir)):
+        master_config = copy.deepcopy(salt_master.config)
+        master_config["pki_check_files"] = False
+        master_config["pki_dir"] = "pki_dir"
+        master_config["root_dir"] = str(config_dir)
+        with salt.utils.files.fopen(str(config_dir / "master"), "w") as fh_:
+            fh_.write(salt.utils.yaml.dump(master_config, default_flow_style=False))
+        ret = salt_key_cli.run(
+            f"--config-dir={config_dir}",
+            "-L",
+        )
+        assert ret.returncode == 0
+        expected = {
+            "minions_rejected": [],
+            "minions_denied": [],
+            "minions_pre": [],
+            "minions": [salt_minion.id, salt_sub_minion.id],
+        }
+        assert ret.data == expected
+
+        bad_key = pki_dir / "minions" / "dir1"
+        bad_key.mkdir()
+
+        ret = salt_key_cli.run(
+            f"--config-dir={config_dir}",
+            "-L",
+        )
+        assert ret.returncode == 0
+        # The directory will show up since there is no file check
+        expected["minions"].insert(0, "dir1")
+        assert ret.data == expected
+
+
 def test_list_all_yaml_out(salt_key_cli, salt_minion, salt_sub_minion):
     """
     test salt-key -L --out=yaml
