@@ -5,7 +5,6 @@ import subprocess
 import pytest
 
 import salt.utils.platform
-from tests.conftest import FIPS_TESTRUN
 
 
 @pytest.fixture
@@ -16,10 +15,6 @@ def salt_master_1(request, salt_factories):
     }
     config_overrides = {
         "interface": "127.0.0.1",
-        "fips_mode": FIPS_TESTRUN,
-        "publish_signing_algorithm": (
-            "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
-        ),
     }
 
     factory = salt_factories.salt_master_daemon(
@@ -43,10 +38,6 @@ def salt_master_2(salt_factories, salt_master_1):
     }
     config_overrides = {
         "interface": "127.0.0.2",
-        "fips_mode": FIPS_TESTRUN,
-        "publish_signing_algorithm": (
-            "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
-        ),
     }
 
     # Use the same ports for both masters, they are binding to different interfaces
@@ -89,9 +80,6 @@ def salt_minion_1(salt_master_1, salt_master_2):
             f"{master_2_addr}:{master_2_port}",
         ],
         "test.foo": "baz",
-        "fips_mode": FIPS_TESTRUN,
-        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
-        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
     }
     factory = salt_master_1.salt_minion_daemon(
         "minion-1",
