@@ -1,5 +1,6 @@
 import pytest
-import salt.ext.tornado.wsgi
+import tornado.wsgi
+
 import salt.netapi.rest_cherrypy.app
 import tests.support.netapi as netapi
 
@@ -7,8 +8,13 @@ cherrypy = pytest.importorskip("cherrypy")
 
 
 @pytest.fixture
-def client_config(client_config, netapi_port):
+def client_config(client_config, netapi_port, request):
     client_config["rest_cherrypy"] = {"port": netapi_port, "debug": True}
+    marker = request.node.get_closest_marker("netapi_client_data")
+    if marker is None:
+        client_config["netapi_enable_clients"] = []
+    else:
+        client_config["netapi_enable_clients"] = marker.args[0]
     return client_config
 
 
@@ -16,7 +22,7 @@ def client_config(client_config, netapi_port):
 def app(client_config, load_auth, salt_minion):
     app, _, cherry_opts = salt.netapi.rest_cherrypy.app.get_app(client_config)
 
-    return salt.ext.tornado.wsgi.WSGIContainer(
+    return tornado.wsgi.WSGIContainer(
         cherrypy.Application(app, "/", config=cherry_opts)
     )
 
@@ -28,8 +34,9 @@ def client_headers(auth_token, content_type_map):
     }
 
 
+# The order of these fixutres matters, app must come before io_loop.
 @pytest.fixture
-def http_server(io_loop, app, netapi_port, client_headers):
+def http_server(app, netapi_port, client_headers, io_loop):
     with netapi.TestsTornadoHttpServer(
         io_loop=io_loop, app=app, port=netapi_port, client_headers=client_headers
     ) as server:
