@@ -1,5 +1,3 @@
-import logging
-
 import pytest
 
 import salt.netapi
@@ -10,22 +8,11 @@ from tests.support.mock import patch
 pytestmark = [
     pytest.mark.slow_test,
     pytest.mark.requires_sshd_server,
-    pytest.mark.skipif(
-        'grains["osfinger"].startswith(("Fedora Linux-40", "Ubuntu-24.04", "Arch Linux"))',
-        reason="System ships with a version of python that is too recent for salt-ssh tests",
-        # Actually, the problem is that the tornado we ship is not prepared for Python 3.12,
-        # and it imports `ssl` and checks if the `match_hostname` function is defined, which
-        # has been deprecated since Python 3.7, so, the logic goes into trying to import
-        # backports.ssl-match-hostname which is not installed on the system.
-    ),
 ]
 
-log = logging.getLogger(__name__)
-
 
 @pytest.fixture
-def client_config(client_config, known_hosts_file):
-    client_config["known_hosts_file"] = str(known_hosts_file)
+def client_config(client_config):
     client_config["netapi_enable_clients"] = ["ssh"]
     return client_config
 
@@ -67,11 +54,18 @@ def salt_auth_account_1(salt_auth_account_1_factory):
         yield account
 
 
+@pytest.fixture(scope="module")
+def salt_auto_account(salt_auto_account_factory):
+    with salt_auto_account_factory as account:
+        yield account
+
+
 def test_ssh(client, auth_creds, salt_ssh_roster_file, rosters_dir, ssh_priv_key):
     low = {
         "client": "ssh",
         "tgt": "localhost",
         "fun": "test.ping",
+        "ignore_host_keys": True,
         "roster_file": str(salt_ssh_roster_file),
         "rosters": [rosters_dir],
         "ssh_priv": ssh_priv_key,
@@ -143,14 +137,16 @@ def test_ssh_disabled(client, auth_creds):
 
 @pytest.mark.timeout_unless_on_windows(360)
 def test_shell_inject_ssh_priv(
-    client, salt_ssh_roster_file, rosters_dir, tmp_path, salt_auto_account
+    client, salt_ssh_roster_file, rosters_dir, tmp_path, salt_auto_account, grains
 ):
     """
     Verify CVE-2020-16846 for ssh_priv variable
     """
+    if grains["os"] == "VMware Photon OS" and grains["osmajorrelease"] == 3:
+        pytest.skip("Skipping problematic test on PhotonOS 3")
     # ZDI-CAN-11143
     path = tmp_path / "test-11143"
-    tgts = ["packages.broadcom.com", "www.zerodayinitiative.com"]
+    tgts = ["repo.saltproject.io", "www.zerodayinitiative.com"]
     ret = None
     for tgt in tgts:
         low = {
@@ -321,6 +317,7 @@ def test_ssh_auth_bypass(client, salt_ssh_roster_file):
         "roster_file": str(salt_ssh_roster_file),
         "rosters": "/",
         "eauth": "xx",
+        "ignore_host_keys": True,
     }
     with pytest.raises(EauthAuthenticationError):
         client.run(low)
