@@ -170,7 +170,7 @@ def test_jid_in_ret_event(salt_run_cli, salt_master, salt_minion, event_listener
         for step_data in orch_job_data["data"][salt_master.id].values():
             assert "__jid__" in step_data
 
-        expected_event_tag = "salt/run/{}/ret".format(jid)
+        expected_event_tag = f"salt/run/{jid}/ret"
         event_pattern = (salt_master.id, expected_event_tag)
 
         matched_events = event_listener.wait_for_events(
@@ -178,7 +178,7 @@ def test_jid_in_ret_event(salt_run_cli, salt_master, salt_minion, event_listener
         )
         assert (
             matched_events.found_all_events
-        ), "Failed to receive the event with the tag '{}'".format(expected_event_tag)
+        ), f"Failed to receive the event with the tag '{expected_event_tag}'"
         for event in matched_events.matches:
             for job_data in event.data["return"]["data"][salt_master.id].values():
                 assert "__jid__" in job_data
@@ -237,7 +237,7 @@ def test_parallel_orchestrations(
         assert duration > 20
         assert duration < 19 * 10 / 2
 
-        expected_event_tag = "salt/run/{}/ret".format(jid)
+        expected_event_tag = f"salt/run/{jid}/ret"
         event_pattern = (salt_master.id, expected_event_tag)
 
         matched_events = event_listener.wait_for_events(
@@ -245,7 +245,7 @@ def test_parallel_orchestrations(
         )
         assert (
             matched_events.found_all_events
-        ), "Failed to receive the event with the tag '{}'".format(expected_event_tag)
+        ), f"Failed to receive the event with the tag '{expected_event_tag}'"
         for event in matched_events.matches:
             for job_data in event.data["return"]["data"][salt_master.id].values():
                 # we expect each duration to be greater than 10s
