@@ -2,49 +2,16 @@
 Simple Smoke Tests for Connected SSH minions
 """
 
-import subprocess
-
-import packaging.version
 import pytest
 from saltfactories.utils.functional import StateResult
 
-import salt.utils.platform
-import salt.utils.versions
-
 pytestmark = [
     pytest.mark.slow_test,
     pytest.mark.skip_on_windows(reason="salt-ssh not available on Windows"),
 ]
 
 
-def _check_systemctl():
-    if not hasattr(_check_systemctl, "memo"):
-        if not salt.utils.platform.is_linux():
-            _check_systemctl.memo = False
-        else:
-            proc = subprocess.run(["systemctl"], capture_output=True, check=False)
-            _check_systemctl.memo = (
-                b"Failed to get D-Bus connection: No such file or directory"
-                in proc.stderr
-            )
-    return _check_systemctl.memo
-
-
-def _check_python():
-    try:
-        proc = subprocess.run(
-            ["/usr/bin/python3", "--version"], capture_output=True, check=False
-        )
-    except FileNotFoundError:
-        return True
-    return packaging.version.Version(
-        proc.stdout.decode().strip().split()[1]
-    ) <= packaging.version.Version("3.10")
-
-
 @pytest.mark.skip_if_not_root
-@pytest.mark.skipif(_check_systemctl(), reason="systemctl degraded")
-@pytest.mark.skipif(_check_python(), reason="System python less than 3.10")
 def test_service(salt_ssh_cli, grains):
     service = "cron"
     os_family = grains["os_family"]
@@ -85,7 +52,7 @@ def _state_tree(salt_master, tmp_path):
     {}/testfile:
       file:
         - managed
-        - contents: "This is a test file"
+        - source: salt://testfile
         - makedirs: true
     """.format(
         tmp_path
@@ -96,6 +63,30 @@ def _state_tree(salt_master, tmp_path):
         yield
 
 
+@pytest.fixture
+def custom_wrapper(salt_run_cli, base_env_state_tree_root_dir):
+    module_contents = r"""\
+def __virtual__():
+    return "grains_custom"
+
+def items():
+    return __grains__.value()
+    """
+    module_dir = base_env_state_tree_root_dir / "_wrapper"
+    module_tempfile = pytest.helpers.temp_file(
+        "grains_custom.py", module_contents, module_dir
+    )
+    try:
+        with module_tempfile:
+            ret = salt_run_cli.run("saltutil.sync_wrapper")
+            assert ret.returncode == 0
+            assert "wrapper.grains_custom" in ret.data
+            yield
+    finally:
+        ret = salt_run_cli.run("saltutil.sync_wrapper")
+        assert ret.returncode == 0
+
+
 @pytest.mark.usefixtures("_state_tree")
 def test_state_apply(salt_ssh_cli):
     ret = salt_ssh_cli.run("state.apply", "core")
@@ -110,3 +101,14 @@ def test_state_highstate(salt_ssh_cli):
     assert ret.returncode == 0
     state_result = StateResult(ret.data)
     assert state_result.result is True
+
+
+@pytest.mark.usefixtures("custom_wrapper")
+def test_custom_wrapper(salt_ssh_cli):
+    ret = salt_ssh_cli.run(
+        "grains_custom.items",
+    )
+    assert ret.returncode == 0
+    assert ret.data
+    assert "id" in ret.data
+    assert ret.data["id"] in ("localhost", "127.0.0.1")
