@@ -124,7 +124,7 @@ def gpg_homedir(salt_master, test_key):
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
             check=True,
-            universal_newlines=True,
+            text=True,
         )
         ret = ProcessResult(
             returncode=proc.returncode,
@@ -140,7 +140,7 @@ def gpg_homedir(salt_master, test_key):
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
             check=True,
-            universal_newlines=True,
+            text=True,
             input=test_key,
         )
         ret = ProcessResult(
@@ -163,7 +163,7 @@ def gpg_homedir(salt_master, test_key):
                     stdout=subprocess.PIPE,
                     stderr=subprocess.STDOUT,
                     check=True,
-                    universal_newlines=True,
+                    text=True,
                     input="KILLAGENT",
                 )
                 ret = ProcessResult(
