@@ -11,8 +11,7 @@ from pytestskipmarkers.utils import platform
 from saltfactories.utils import random_string
 
 import salt.config
-import salt.utils.files
-from tests.conftest import CODE_DIR, FIPS_TESTRUN
+from tests.conftest import CODE_DIR
 from tests.support.pkg import ApiRequest, SaltMaster, SaltMasterWindows, SaltPkgInstall
 
 log = logging.getLogger(__name__)
@@ -34,16 +33,6 @@ def _system_up_to_date(
     grains,
     shell,
 ):
-    gpg_dest = "/etc/apt/keyrings/salt-archive-keyring.gpg"
-    if os.path.exists(gpg_dest):
-        with salt.utils.files.fopen(gpg_dest, "r") as fp:
-            log.error("Salt gpg key is %s", fp.read())
-    else:
-        log.error("Salt gpg not present")
-    # download_file(
-    #    "https://packages.broadcom.com/artifactory/api/security/keypair/SaltProjectKey/public",
-    #    gpg_dest,
-    # )
     if grains["os_family"] == "Debian":
         ret = shell.run("apt", "update")
         assert ret.returncode == 0
@@ -100,6 +89,12 @@ def pytest_addoption(parser):
         action="store_true",
         help="Do not uninstall salt packages after test run is complete",
     )
+    test_selection_group.addoption(
+        "--classic",
+        default=False,
+        action="store_true",
+        help="Test an upgrade from the classic packages.",
+    )
     test_selection_group.addoption(
         "--prev-version",
         action="store",
@@ -118,72 +113,13 @@ def pytest_addoption(parser):
     )
 
 
-@pytest.hookimpl(hookwrapper=True, trylast=True)
-def pytest_collection_modifyitems(config, items):
-    """
-    called after collection has been performed, may filter or re-order
-    the items in-place.
-
-    :param _pytest.main.Session session: the pytest session object
-    :param _pytest.config.Config config: pytest config object
-    :param List[_pytest.nodes.Item] items: list of item objects
-    """
-    # Let PyTest or other plugins handle the initial collection
-    yield
-    selected = []
-    deselected = []
-    pkg_tests_path = pathlib.Path(__file__).parent
-
-    if config.getoption("--upgrade"):
-        for item in items:
-            if str(item.fspath).startswith(str(pkg_tests_path / "upgrade")):
-                selected.append(item)
-            else:
-                deselected.append(item)
-        # re-order test_salt_upgrade.py to last - this ensures that salt is
-        # set up correctly for integration tests
-        for idx, item in enumerate(selected):
-            if str(item.fspath).endswith("test_salt_upgrade.py"):
-                selected.append(selected.pop(idx))
-                break
-    elif config.getoption("--downgrade"):
-        for item in items:
-            if str(item.fspath).startswith(str(pkg_tests_path / "downgrade")):
-                selected.append(item)
-            else:
-                deselected.append(item)
-    elif config.getoption("--download-pkgs"):
-        for item in items:
-            if str(item.fspath).startswith(str(pkg_tests_path / "download")):
-                selected.append(item)
-            else:
-                deselected.append(item)
-    else:
-        exclude_paths = (
-            str(pkg_tests_path / "upgrade"),
-            str(pkg_tests_path / "downgrade"),
-            str(pkg_tests_path / "download"),
-        )
-        for item in items:
-            if str(item.fspath).startswith(exclude_paths):
-                deselected.append(item)
-            else:
-                selected.append(item)
-
-    if deselected:
-        # Selection changed
-        items[:] = selected
-        config.hook.pytest_deselected(items=deselected)
-
-
 @pytest.hookimpl(tryfirst=True)
 def pytest_runtest_setup(item):
     """
     Fixtures injection based on markers or test skips based on CLI arguments
     """
-    pkg_tests_path = pathlib.Path(__file__).parent
     if (
-        str(item.fspath).startswith(str(pkg_tests_path / "download"))
+        str(item.fspath).startswith(str(pathlib.Path(__file__).parent / "download"))
         and item.config.getoption("--download-pkgs") is False
     ):
         raise pytest.skip.Exception(
@@ -192,17 +128,6 @@ def pytest_runtest_setup(item):
             _use_item_location=True,
         )
 
-    for key in ("upgrade", "downgrade"):
-        if (
-            str(item.fspath).startswith(str(pkg_tests_path / key))
-            and item.config.getoption(f"--{key}") is False
-        ):
-            raise pytest.skip.Exception(
-                f"The package {key} tests are disabled. Pass '--{key}' to pytest "
-                "to enable them.",
-                _use_item_location=True,
-            )
-
 
 @pytest.fixture(scope="session")
 def salt_factories_root_dir(request, tmp_path_factory):
@@ -234,17 +159,14 @@ def salt_factories_config(salt_factories_root_dir):
 
 @pytest.fixture(scope="session")
 def install_salt(request, salt_factories_root_dir):
-    if platform.is_windows():
-        conf_dir = "c:/salt/etc/salt"
-    else:
-        conf_dir = salt_factories_root_dir / "etc" / "salt"
     with SaltPkgInstall(
-        conf_dir=conf_dir,
+        conf_dir=salt_factories_root_dir / "etc" / "salt",
         pkg_system_service=request.config.getoption("--pkg-system-service"),
         upgrade=request.config.getoption("--upgrade"),
         downgrade=request.config.getoption("--downgrade"),
         no_uninstall=request.config.getoption("--no-uninstall"),
         no_install=request.config.getoption("--no-install"),
+        classic=request.config.getoption("--classic"),
         prev_version=request.config.getoption("--prev-version"),
         use_prev_version=request.config.getoption("--use-prev-version"),
     ) as fixture:
@@ -311,25 +233,18 @@ def salt_master(salt_factories, install_salt, pkg_tests_account):
             },
         },
         "fips_mode": FIPS_TESTRUN,
-        "publish_signing_algorithm": (
-            "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
-        ),
         "open_mode": True,
     }
-    salt_user_in_config_file = False
+    test_user = False
     master_config = install_salt.config_path / "master"
-    if master_config.exists() and master_config.stat().st_size:
+    if master_config.exists():
         with salt.utils.files.fopen(master_config) as fp:
             data = yaml.safe_load(fp)
-            if data is None:
-                # File exists but is mostly commented out
-                data = {}
-            user_in_config_file = data.get("user")
-            if user_in_config_file and user_in_config_file == "salt":
-                salt_user_in_config_file = True
+            if data and "user" in data:
+                test_user = True
                 # We are testing a different user, so we need to test the system
                 # configs, or else permissions will not be correct.
-                config_overrides["user"] = user_in_config_file
+                config_overrides["user"] = data["user"]
                 config_overrides["log_file"] = salt.config.DEFAULT_MASTER_OPTS.get(
                     "log_file"
                 )
@@ -355,22 +270,23 @@ def salt_master(salt_factories, install_salt, pkg_tests_account):
                     pathlib.Path("/var", "cache", "salt", "master"),
                 ]
                 for _file in verify_files:
-                    if _file.owner() != "salt":
-                        log.warning(
-                            "The owner of '%s' is '%s' when it should be 'salt'",
-                            _file,
-                            _file.owner(),
-                        )
-                    if _file.group() != "salt":
-                        log.warning(
-                            "The group of '%s' is '%s' when it should be 'salt'",
-                            _file,
-                            _file.group(),
-                        )
+                    assert _file.owner() == "salt"
+                    assert _file.group() == "salt"
 
     master_script = False
     if platform.is_windows():
-        master_script = True
+        if install_salt.classic:
+            master_script = True
+        if install_salt.relenv:
+            master_script = True
+        elif not install_salt.upgrade:
+            master_script = True
+        if (
+            not install_salt.relenv
+            and install_salt.use_prev_version
+            and not install_salt.classic
+        ):
+            master_script = False
 
     if master_script:
         salt_factories.system_service = False
@@ -378,10 +294,14 @@ def salt_master(salt_factories, install_salt, pkg_tests_account):
         scripts_dir = salt_factories.root_dir / "Scripts"
         scripts_dir.mkdir(exist_ok=True)
         salt_factories.scripts_dir = scripts_dir
-        python_executable = install_salt.install_dir / "Scripts" / "python.exe"
+        python_executable = install_salt.bin_dir / "Scripts" / "python.exe"
+        if install_salt.classic:
+            python_executable = install_salt.bin_dir / "python.exe"
+        if install_salt.relenv:
+            python_executable = install_salt.install_dir / "Scripts" / "python.exe"
         salt_factories.python_executable = python_executable
         factory = salt_factories.salt_master_daemon(
-            "pkg-test-master",
+            random_string("master-"),
             defaults=config_defaults,
             overrides=config_overrides,
             factory_class=SaltMasterWindows,
@@ -389,15 +309,19 @@ def salt_master(salt_factories, install_salt, pkg_tests_account):
         )
         salt_factories.system_service = True
     else:
+
+        if install_salt.classic and platform.is_darwin():
+            os.environ["PATH"] += ":/opt/salt/bin"
+
         factory = salt_factories.salt_master_daemon(
-            "pkg-test-master",
+            random_string("master-"),
             defaults=config_defaults,
             overrides=config_overrides,
             factory_class=SaltMaster,
             salt_pkg_install=install_salt,
         )
     factory.after_terminate(pytest.helpers.remove_stale_master_key, factory)
-    if salt_user_in_config_file:
+    if test_user:
         # Salt factories calls salt.utils.verify.verify_env
         # which sets root perms on /etc/salt/pki/master since we are running
         # the test suite as root, but we want to run Salt master as salt
@@ -446,18 +370,23 @@ def salt_minion(salt_factories, salt_master, install_salt):
         "file_roots": salt_master.config["file_roots"].copy(),
         "pillar_roots": salt_master.config["pillar_roots"].copy(),
         "fips_mode": FIPS_TESTRUN,
-        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
-        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
+        "open_mode": True,
     }
     if platform.is_windows():
-        config_overrides["winrepo_dir"] = (
-            rf"{salt_factories.root_dir}\srv\salt\win\repo"
-        )
-        config_overrides["winrepo_dir_ng"] = (
-            rf"{salt_factories.root_dir}\srv\salt\win\repo_ng"
-        )
+        config_overrides[
+            "winrepo_dir"
+        ] = rf"{salt_factories.root_dir}\srv\salt\win\repo"
+        config_overrides[
+            "winrepo_dir_ng"
+        ] = rf"{salt_factories.root_dir}\srv\salt\win\repo_ng"
         config_overrides["winrepo_source_dir"] = r"salt://win/repo_ng"
 
+    if install_salt.classic and platform.is_windows():
+        salt_factories.python_executable = None
+
+    if install_salt.classic and platform.is_darwin():
+        os.environ["PATH"] += ":/opt/salt/bin"
+
     factory = salt_master.salt_minion_daemon(
         minion_id,
         overrides=config_overrides,
@@ -468,31 +397,13 @@ def salt_minion(salt_factories, salt_master, install_salt):
     # which sets root perms on /srv/salt and /srv/pillar since we are running
     # the test suite as root, but we want to run Salt master as salt
     if not platform.is_windows() and not platform.is_darwin():
-        import pwd
-
-        try:
-            pwd.getpwnam("salt")
-        except KeyError:
-            # The salt user does not exist
-            pass
-        else:
-            state_tree = "/srv/salt"
-            pillar_tree = "/srv/pillar"
-            check_paths = [state_tree, pillar_tree, CODE_DIR / ".nox"]
-            for path in check_paths:
-                if os.path.exists(path) is False:
-                    continue
-                subprocess.run(["chown", "-R", "salt:salt", str(path)], check=False)
-
-    if platform.is_windows():
-        minion_pki = pathlib.Path("c:/salt/etc/salt/pki")
-        if minion_pki.exists():
-            salt.utils.files.rm_rf(minion_pki)
-
-        # Work around missing WMIC until 3008.10 has been released.
-        grainsdir = pathlib.Path("c:/salt/etc/grains")
-        grainsdir.mkdir(exist_ok=True)
-        shutil.copy(r"salt\grains\disks.py", grainsdir)
+        state_tree = "/srv/salt"
+        pillar_tree = "/srv/pillar"
+        check_paths = [state_tree, pillar_tree, CODE_DIR / ".nox"]
+        for path in check_paths:
+            if os.path.exists(path) is False:
+                continue
+            subprocess.run(["chown", "-R", "salt:salt", str(path)], check=False)
 
     factory.after_terminate(
         pytest.helpers.remove_stale_minion_key, salt_master, factory.id
@@ -545,12 +456,7 @@ def salt_api(salt_master, install_salt, extras_pypath):
     """
     start up and configure salt_api
     """
-    # There are some pip tests in tests/pytests/pkg/integration/test_pip.py
-    # that are installing cffi into extras directory. So removing it causes
-    # lots of tests to break where cffi can't be found anymore. This still
-    # needs to be fixed.
-    #
-    # shutil.rmtree(str(extras_pypath), ignore_errors=True)
+    shutil.rmtree(str(extras_pypath), ignore_errors=True)
     start_timeout = None
     factory = salt_master.salt_api_daemon()
     with factory.started(start_timeout=start_timeout):
@@ -563,23 +469,3 @@ def api_request(pkg_tests_account, salt_api):
         port=salt_api.config["rest_cherrypy"]["port"], account=pkg_tests_account
     ) as session:
         yield session
-
-
-@pytest.fixture(scope="module")
-def debian_disable_policy_rcd(grains):
-    """
-    This fixture is used to disable the /usr/sbin/policy-rc.d file on
-    Debian-based systems. This is present on container images and prevents the
-    restart of services during package installation or upgrade.
-    This is needed where we want to test pkg behaviour exactly as it would be on
-    a real system.
-
-    """
-    if grains["os_family"] == "Debian":
-        policy_rcd_path = pathlib.Path("/usr/sbin/policy-rc.d")
-        if policy_rcd_path.exists():
-            policy_rcd_path.rename(policy_rcd_path.with_suffix(".disabled"))
-            yield
-            policy_rcd_path.with_suffix(".disabled").rename(policy_rcd_path)
-    else:
-        yield
