@@ -1,16 +1,13 @@
 """
 Test Salt Pkg Downloads
 """
-
 import contextlib
 import logging
 import os
 import pathlib
 import shutil
-import time
 
-import packaging.version
-import psutil
+import packaging
 import pytest
 from pytestskipmarkers.utils import platform
 
@@ -100,7 +97,7 @@ def get_salt_release():
         salt_release = "3006.0rc2"
     if pkg_test_type == "download-pkgs":
         if packaging.version.parse(salt_release) < packaging.version.parse("3006.0rc1"):
-            log.warning("The salt release being tested, %r looks off.", salt_release)
+            log.warning(f"The salt release being tested, {salt_release!r} looks off.")
     return salt_release
 
 
@@ -112,9 +109,7 @@ def get_repo_subpath_params():
         latest_release = packaging.version.parse(latest_env_var)
         if current_release >= latest_release:
             log.debug(
-                "Running the tests for the latest release since %s >= %s",
-                current_release,
-                latest_release,
+                f"Running the tests for the latest release since {str(current_release)} >= {str(latest_release)}"
             )
             params.append("latest")
     return params
@@ -462,12 +457,11 @@ def setup_windows(
     repo_subpath,
     package_type,
     onedir_install_path,
-    timeout=300,
 ):
     try:
         arch = os.environ.get("SALT_REPO_ARCH") or "amd64"
         if package_type != "onedir":
-            root_dir = pathlib.Path(os.getenv("ProgramFiles"), "Salt Project", "Salt")
+            root_dir = pathlib.Path(r"C:\Program Files\Salt Project\Salt")
 
             if packaging.version.parse(salt_release) > packaging.version.parse("3005"):
                 if package_type.lower() == "nsis":
@@ -494,45 +488,6 @@ def setup_windows(
 
             pytest.helpers.download_file(win_pkg_url, pkg_path)
             if package_type.lower() == "nsis":
-                # We need to make sure there are no installer/uninstaller
-                # processes running. Uninst.exe launches a 2nd binary
-                # (Un.exe or Un_*.exe) Let's get the name of the process
-                processes = [
-                    win_pkg,
-                    "uninst.exe",
-                    "Un.exe",
-                    "Un_A.exe",
-                    "Un_B.exe",
-                    "Un_C.exe",
-                    "Un_D.exe",
-                    "Un_D.exe",
-                    "Un_F.exe",
-                    "Un_G.exe",
-                ]
-                proc_name = ""
-                for proc in processes:
-                    try:
-                        if proc in (p.name() for p in psutil.process_iter()):
-                            proc_name = proc
-                    except psutil.NoSuchProcess:
-                        continue
-
-                # We need to give the process time to exit. We'll timeout after
-                # 5 minutes or whatever timeout is set to
-                if proc_name:
-                    elapsed_time = 0
-                    while elapsed_time < timeout:
-                        try:
-                            if proc_name not in (
-                                p.name() for p in psutil.process_iter()
-                            ):
-                                break
-                        except psutil.NoSuchProcess:
-                            continue
-                        elapsed_time += 0.1
-                        time.sleep(0.1)
-
-                # Only run setup when we're sure no other installations are running
                 ret = shell.run(str(pkg_path), "/start-minion=0", "/S", check=False)
             else:
                 ret = shell.run(
@@ -598,7 +553,6 @@ def salt_test_command(request, install_dir):
     return command
 
 
-@pytest.mark.skip_on_windows(reason="This is flaky on Windows")
 @pytest.mark.parametrize("salt_test_command", get_salt_test_commands(), indirect=True)
 def test_download(shell, salt_test_command):
     """
