@@ -2,7 +2,6 @@ import os
 import pathlib
 import subprocess
 import sys
-import time
 
 import packaging.version
 import psutil
@@ -10,33 +9,11 @@ import pytest
 from saltfactories.utils.tempfiles import temp_directory
 
 pytestmark = [
-    pytest.mark.skip_unless_on_linux,
+    pytest.mark.skip_on_windows,
+    pytest.mark.skip_on_darwin,
 ]
 
 
-@pytest.fixture
-def salt_systemd_setup(
-    install_salt,
-    salt_call_cli,
-):
-    """
-    Fixture to set systemd for salt packages to enabled and active
-    Note: assumes Salt packages already installed
-    """
-    install_salt.install()
-
-    # ensure known state, enabled and active
-    test_list = ["salt-api", "salt-minion", "salt-master"]
-    for test_item in test_list:
-        test_cmd = f"systemctl enable {test_item}"
-        ret = salt_call_cli.run("--local", "cmd.run", test_cmd)
-        assert ret.returncode == 0
-
-        test_cmd = f"systemctl restart {test_item}"
-        ret = salt_call_cli.run("--local", "cmd.run", test_cmd)
-        assert ret.returncode == 0
-
-
 @pytest.fixture
 def pkg_paths():
     """
@@ -68,12 +45,8 @@ def pkg_paths_salt_user():
         "/var/log/salt/master",
         "/var/log/salt/api",
         "/var/log/salt/key",
-        "/var/log/salt/syndic",
         "/var/cache/salt/master",
         "/var/run/salt/master",
-        "/run/salt-master.pid",
-        "/run/salt-syndic.pid",
-        "/run/salt-api.pid",
     ]
 
 
@@ -88,18 +61,16 @@ def pkg_paths_salt_user_exclusions():
     return paths
 
 
-def test_salt_user_master(install_salt, salt_master):
+@pytest.fixture(autouse=True)
+def _skip_on_non_relenv(install_salt):
+    if not install_salt.relenv:
+        pytest.skip("The salt user only exists on relenv versions of salt")
+
+
+def test_salt_user_master(salt_master, install_salt):
     """
     Test the correct user is running the Salt Master
     """
-    for count in range(0, 30):
-        if salt_master.is_running():
-            break
-        else:
-            time.sleep(2)
-
-    assert salt_master.is_running()
-
     match = False
     for proc in psutil.Process(salt_master.pid).children():
         assert proc.username() == "salt"
@@ -108,12 +79,10 @@ def test_salt_user_master(install_salt, salt_master):
     assert match
 
 
-def test_salt_user_home(install_salt, salt_master):
+def test_salt_user_home(install_salt):
     """
     Test the salt user's home is /opt/saltstack/salt
     """
-    assert salt_master.is_running()
-
     proc = subprocess.run(
         ["getent", "passwd", "salt"], check=False, capture_output=True
     )
@@ -126,12 +95,10 @@ def test_salt_user_home(install_salt, salt_master):
     assert home == "/opt/saltstack/salt"
 
 
-def test_salt_user_group(install_salt, salt_master):
+def test_salt_user_group(install_salt):
     """
     Test the salt user is in the salt group
     """
-    assert salt_master.is_running()
-
     proc = subprocess.run(["id", "salt"], check=False, capture_output=True)
     assert proc.returncode == 0
     in_group = False
@@ -144,12 +111,10 @@ def test_salt_user_group(install_salt, salt_master):
     assert in_group is True
 
 
-def test_salt_user_shell(install_salt, salt_master):
+def test_salt_user_shell(install_salt):
     """
     Test the salt user's login shell
     """
-    assert salt_master.is_running()
-
     proc = subprocess.run(
         ["getent", "passwd", "salt"], check=False, capture_output=True
     )
@@ -165,11 +130,7 @@ def test_salt_user_shell(install_salt, salt_master):
 
 
 def test_pkg_paths(
-    install_salt,
-    pkg_paths,
-    pkg_paths_salt_user,
-    pkg_paths_salt_user_exclusions,
-    salt_call_cli,
+    install_salt, pkg_paths, pkg_paths_salt_user, pkg_paths_salt_user_exclusions
 ):
     """
     Test package paths ownership
@@ -178,19 +139,12 @@ def test_pkg_paths(
         "3006.4"
     ):
         pytest.skip("Package path ownership was changed in salt 3006.4")
-
-    if install_salt.distro_name == "photon" and install_salt.distro_version == "5":
-        # Fails on upgrade tests but there is no way to check that we are running an upgrade test.
-        pytest.skip("Package path ownership fails on photon 5")
-
     salt_user_subdirs = []
-
     for _path in pkg_paths:
         pkg_path = pathlib.Path(_path)
         assert pkg_path.exists()
         for dirpath, sub_dirs, files in os.walk(pkg_path):
             path = pathlib.Path(dirpath)
-
             # Directories owned by salt:salt or their subdirs/files
             if (
                 str(path) in pkg_paths_salt_user or str(path) in salt_user_subdirs
@@ -210,8 +164,6 @@ def test_pkg_paths(
                 assert path.owner() == "root"
                 assert path.group() == "root"
                 for file in files:
-                    if file.endswith("ipc"):
-                        continue
                     file_path = path.joinpath(file)
                     # Individual files owned by salt user
                     if str(file_path) in pkg_paths_salt_user:
@@ -223,11 +175,7 @@ def test_pkg_paths(
 
 @pytest.mark.skip_if_binaries_missing("logrotate")
 def test_paths_log_rotation(
-    install_salt,
-    salt_master,
-    salt_minion,
-    salt_call_cli,
-    pkg_tests_account,
+    salt_master, salt_minion, salt_call_cli, install_salt, pkg_tests_account
 ):
     """
     Test the correct ownership is assigned when log rotation occurs
@@ -235,26 +183,18 @@ def test_paths_log_rotation(
     Check ownership and premissions.
     Assumes test_pkg_paths successful
     """
-    pytest.skip(
-        "Test has too many side effects that cause other tests to fail. needs refactor"
-    )
     if packaging.version.parse(install_salt.version) <= packaging.version.parse(
         "3006.4"
     ):
         pytest.skip("Package path ownership was changed in salt 3006.4")
 
-    if install_salt.distro_id not in (
-        "almalinux",
-        "rocky",
-        "centos",
-        "redhat",
-        "amzn",
-        "fedora",
-    ):
+    if install_salt.distro_id not in ("centos", "redhat", "amzn", "fedora"):
         pytest.skip(
             "Only tests RedHat family packages till logrotation paths are resolved on Ubuntu/Debian, see issue 65231"
         )
 
+    # check that the salt_master is running
+    assert salt_master.is_running()
     match = False
     for proc in psutil.Process(salt_master.pid).children():
         assert proc.username() == "salt"
@@ -356,7 +296,7 @@ def test_paths_log_rotation(
                                 for _path in log_files_list:
                                     log_path = pathlib.Path(_path)
                                     assert log_path.exists()
-                                    with log_path.open("a", encoding="utf-8") as f:
+                                    with log_path.open("a") as f:
                                         f.write("This is a log rotation test\n")
 
                                 # force log rotation
@@ -421,7 +361,3 @@ def test_paths_log_rotation(
 
                                 bkup_count += 1
                                 assert ret.returncode == 0
-
-    # ensure leave salt_master running
-    salt_master.start()
-    assert salt_master.is_running() is True
