@@ -8,7 +8,6 @@ import pytest
 from pytestshellutils.exceptions import FactoryTimeout
 
 import salt.utils.platform
-from tests.conftest import FIPS_TESTRUN
 
 log = logging.getLogger(__name__)
 
@@ -21,11 +20,8 @@ def salt_mm_master_1(request, salt_factories):
     }
     config_overrides = {
         "interface": "127.0.0.1",
-        "fips_mode": FIPS_TESTRUN,
-        "publish_signing_algorithm": (
-            "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
-        ),
     }
+
     factory = salt_factories.salt_master_daemon(
         "mm-master-1",
         defaults=config_defaults,
@@ -52,10 +48,6 @@ def salt_mm_master_2(salt_factories, salt_mm_master_1):
     }
     config_overrides = {
         "interface": "127.0.0.2",
-        "fips_mode": FIPS_TESTRUN,
-        "publish_signing_algorithm": (
-            "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
-        ),
     }
 
     # Use the same ports for both masters, they are binding to different interfaces
@@ -99,13 +91,10 @@ def salt_mm_minion_1(salt_mm_master_1, salt_mm_master_2):
     mm_master_2_addr = salt_mm_master_2.config["interface"]
     config_overrides = {
         "master": [
-            f"{mm_master_1_addr}:{mm_master_1_port}",
-            f"{mm_master_2_addr}:{mm_master_2_port}",
+            "{}:{}".format(mm_master_1_addr, mm_master_1_port),
+            "{}:{}".format(mm_master_2_addr, mm_master_2_port),
         ],
         "test.foo": "baz",
-        "fips_mode": FIPS_TESTRUN,
-        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
-        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
     }
     factory = salt_mm_master_1.salt_minion_daemon(
         "mm-minion-1",
@@ -129,13 +118,10 @@ def salt_mm_minion_2(salt_mm_master_1, salt_mm_master_2):
     mm_master_2_addr = salt_mm_master_2.config["interface"]
     config_overrides = {
         "master": [
-            f"{mm_master_1_addr}:{mm_master_1_port}",
-            f"{mm_master_2_addr}:{mm_master_2_port}",
+            "{}:{}".format(mm_master_1_addr, mm_master_1_port),
+            "{}:{}".format(mm_master_2_addr, mm_master_2_port),
         ],
         "test.foo": "baz",
-        "fips_mode": FIPS_TESTRUN,
-        "encryption_algorithm": "OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
-        "signing_algorithm": "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
     }
     factory = salt_mm_master_2.salt_minion_daemon(
         "mm-minion-2",
@@ -171,7 +157,7 @@ def run_salt_cmds():
                 for cli in list(clis_to_check[minion]):
                     try:
                         ret = cli.run(
-                            f"--timeout={timeout}",
+                            "--timeout={}".format(timeout),
                             "test.ping",
                             minion_tgt=minion,
                             _timeout=2 * timeout,
