@@ -38,7 +38,7 @@ def host_docker_network_ip_address(docker_network_name):
         try:
             assert ret["result"]
         except AssertionError:
-            pytest.skip("Failed to create docker network: {}".format(ret))
+            pytest.skip(f"Failed to create docker network: {ret}")
         yield network_gateway
     finally:
         sminion.states.docker_network.absent(docker_network_name)
@@ -122,5 +122,5 @@ def file_add_delete_sls(testfile_path, state_tree):
     """.format(
         path=testfile_path
     )
-    with pytest.helpers.temp_file("{}.sls".format(sls_name), sls_contents, state_tree):
+    with pytest.helpers.temp_file(f"{sls_name}.sls", sls_contents, state_tree):
         yield sls_name
