@@ -1,11 +1,11 @@
-import importlib
+import logging
 import subprocess
 import types
 
 import pytest
 
 import salt.client.ssh.shell as shell
-from tests.support.mock import MagicMock, PropertyMock, patch
+from tests.support.mock import MagicMock, PropertyMock, call, patch
 
 
 @pytest.fixture
@@ -55,48 +55,6 @@ def test_ssh_shell_exec_cmd(caplog):
         assert passwd not in caplog.text
 
 
-@pytest.mark.parametrize(
-    "text, sanitize, expected",
-    [
-        ("-oServerAliveInterval=60", "Server", "-oServerAliveInterval=60"),
-        (
-            "-o ServerAliveInterval=60 --password Server",
-            "Server",
-            "-o ServerAliveInterval=60 --password ******",
-        ),
-    ],
-)
-def test_ssh_shell_sanitize(text, sanitize, expected):
-    """
-    Test that _sanitize_str doesn't replace strings inside of other words.
-    """
-    shl = shell.Shell({}, "localhost")
-    res = shl._sanitize_str(text, sanitize)
-
-    assert res == expected
-
-
-def test_run_cmd_password_prompt():
-    """
-    When using a password that has the same value as the shell
-    buffer, test that the sanitization is done after internal
-    matching, e.g. with "SSH_PRIVATE_KEY_PASSWORD_PROMPT_RE".
-    """
-    passwd = "password"
-    shl = shell.Shell({}, "localhost", passwd=passwd)
-    mock_ssh_re = MagicMock()
-
-    mock_term = MagicMock()
-    mock_term.recv.return_value = (passwd, None)
-
-    with patch.object(shell, "SSH_PRIVATE_KEY_PASSWORD_PROMPT_RE", mock_ssh_re), patch(
-        "salt.utils.vt.Terminal", return_value=mock_term
-    ):
-        shl._run_cmd("test_cmd")
-
-    mock_ssh_re.search.assert_called_once_with(passwd)
-
-
 def test_ssh_shell_exec_cmd_waits_for_term_close_before_reading_exit_status():
     """
     Ensure that the terminal is always closed before accessing its exitstatus.
@@ -143,46 +101,27 @@ def test_ssh_shell_exec_cmd_returns_status_code_with_highest_bit_set_if_process_
     assert retcode == 137
 
 
-@pytest.fixture()
-def mock_bin_paths():
-    """Automatically apply fixture to all tests that need it."""
-    with patch("salt.utils.path.which") as mock_which:
-        mock_which.side_effect = lambda x: {
-            "ssh-keygen": "/custom/ssh-keygen",
-            "ssh": "/custom/ssh",
-            "scp": "/custom/scp",
-        }.get(x, None)
-        importlib.reload(shell)
-        yield
-    importlib.reload(shell)
+def exec_cmd(cmd):
+    if cmd.startswith("mkdir -p"):
+        return "", "Not a directory", 1
+    return "OK", "", 0
 
 
-def test_gen_key_uses_custom_ssh_keygen_path(mock_bin_paths):
-    """Test that gen_key function uses the correct ssh-keygen path."""
-    with patch("subprocess.call") as mock_call:
-        shell.gen_key("/dev/null")
-
-        # Extract the first argument of the first call to subprocess.call
-        args, _ = mock_call.call_args
-
-        # Assert that the first part of the command is the custom ssh-keygen path
-        assert args[0][0] == "/custom/ssh-keygen"
+def test_ssh_shell_send_makedirs_failure_returns_immediately():
+    with patch("salt.client.ssh.shell.Shell.exec_cmd", side_effect=exec_cmd):
+        shl = shell.Shell({}, "localhost")
+        stdout, stderr, retcode = shl.send("/tmp/file", "/tmp/file", True)
+    assert retcode == 1
+    assert "Not a directory" in stderr
 
 
-def test_ssh_command_execution_uses_custom_path(mock_bin_paths):
-    options = {"_ssh_version": (4, 9)}
-    _shell = shell.Shell(opts=options, host="example.com")
-    cmd_string = _shell._cmd_str("ls -la")
-    assert "/custom/ssh" in cmd_string
-
-
-def test_scp_command_execution_uses_custom_path(mock_bin_paths):
-    _shell = shell.Shell(opts={}, host="example.com")
-    with patch.object(
-        _shell, "_run_cmd", return_value=(None, None, None)
-    ) as mock_run_cmd:
-        _shell.send("source_file.txt", "/path/dest_file.txt")
-        # The command string passed to _run_cmd should include the custom scp path
-        args, _ = mock_run_cmd.call_args
-        assert "/custom/scp" in args[0]
-        assert "source_file.txt example.com:/path/dest_file.txt" in args[0]
+def test_ssh_shell_send_makedirs_on_relative_filename_skips_exec(caplog):
+    with patch("salt.client.ssh.shell.Shell.exec_cmd", side_effect=exec_cmd) as cmd:
+        with patch("salt.client.ssh.shell.Shell._run_cmd", return_value=("", "", 0)):
+            shl = shell.Shell({}, "localhost")
+            with caplog.at_level(logging.WARNING):
+                stdout, stderr, retcode = shl.send("/tmp/file", "targetfile", True)
+    assert retcode == 0
+    assert "Not a directory" not in stderr
+    assert call("mkdir -p ''") not in cmd.mock_calls
+    assert "Makedirs called on relative filename" in caplog.text
