@@ -2,6 +2,7 @@
     :codeauthor: jmoney <justin@saltstack.com>
 """
 
+
 import pytest
 
 import salt.channel.client
@@ -27,7 +28,6 @@ def test__render_filenames_undefined_template():
     dest = "/srv/salt/cheese"
     saltenv = "base"
     template = "biscuits"
-    ret = (path, dest)
     pytest.raises(
         CommandExecutionError, cp._render_filenames, path, dest, saltenv, template
     )
@@ -42,10 +42,7 @@ def test__render_filenames_render_failed():
     saltenv = "base"
     template = "jinja"
     file_data = "Remember to keep your files well salted."
-
-    def mock_jinja(*args, **kwargs):
-        return {"result": False, "data": file_data}
-
+    mock_jinja = lambda *args, **kwargs: {"result": False, "data": file_data}
     with patch.dict(templates.TEMPLATE_REGISTRY, {"jinja": mock_jinja}):
         with patch("salt.utils.files.fopen", mock_open(read_data=file_data)):
             pytest.raises(
@@ -67,10 +64,7 @@ def test__render_filenames_success():
     saltenv = "base"
     template = "jinja"
     file_data = "/srv/salt/biscuits"
-
-    def mock_jinja(*args, **kwargs):
-        return {"result": True, "data": file_data}
-
+    mock_jinja = lambda *args, **kwargs: {"result": True, "data": file_data}
     ret = (file_data, file_data)  # salt.utils.files.fopen can only be mocked once
     with patch.dict(templates.TEMPLATE_REGISTRY, {"jinja": mock_jinja}):
         with patch("salt.utils.files.fopen", mock_open(read_data=file_data)):
@@ -99,7 +93,6 @@ def test_get_file_str_success():
     path = "salt://saltines"
     dest = "/srv/salt/cheese/saltines"
     file_data = "Remember to keep your files well salted."
-    saltenv = "base"
     ret = file_data
     with patch("salt.utils.files.fopen", mock_open(read_data=file_data)):
         with patch("salt.modules.cp.cache_file", MagicMock(return_value=dest)):
@@ -142,9 +135,7 @@ def test_push():
     ), patch.multiple(
         "salt.modules.cp",
         _auth=MagicMock(**{"return_value.gen_token.return_value": "token"}),
-        __opts__=salt.loader.dunder.__opts__.with_default(
-            {"id": "abc", "file_buffer_size": 10}
-        ),
+        __opts__={"id": "abc", "file_buffer_size": 10},
     ), patch(
         "salt.utils.files.fopen", mock_open(read_data=b"content")
     ) as m_open, patch(
@@ -156,11 +147,11 @@ def test_push():
         assert num_opens == 1, num_opens
         fh_ = m_open.filehandles[filename][0]
         assert fh_.read.call_count == 2, fh_.read.call_count
-
-        req_channel_factory_mock().__enter__().send.assert_called_once_with(  # pylint: disable=unnecessary-dunder-call
+        req_channel_factory_mock().__enter__().send.assert_called_once_with(
             dict(
                 loc=fh_.tell(),  # pylint: disable=resource-leakage
                 cmd="_file_recv",
+                tok="token",
                 path=["saltines", "test.file"],
                 size=10,
                 data=b"",  # data is empty here because load['data'] is overwritten
