@@ -4,16 +4,21 @@
 
 import datetime
 import logging
-from collections import OrderedDict
 
 import pytest
 
 import salt.modules.schedule as schedule
+import salt.utils.odict
 from salt.utils.event import SaltEvent
+from salt.utils.odict import OrderedDict
 from tests.support.mock import MagicMock, call, mock_open, patch
 
 log = logging.getLogger(__name__)
 
+pytestmark = [
+    pytest.mark.usefixtures("mocked_tcp_pub_client"),
+]
+
 
 @pytest.fixture
 def job1():
@@ -47,15 +52,14 @@ def test_purge(job1):
     patch_schedule_get_event = patch.object(
         SaltEvent, "get_event", return_value={"complete": True, "schedule": {}}
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
     patch_schedule_list = patch.object(
         schedule, "list_", MagicMock(return_value=_schedule_data)
     )
 
-    with (
-        patch_makedirs
-    ), (
-        patch_schedule_opts
-    ), patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_list:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_connect_pub, patch_schedule_list:
         assert schedule.purge() == {
             "comment": ["Deleted job: job1 from schedule."],
             "changes": {"job1": "removed"},
@@ -105,10 +109,11 @@ def test_delete(job1):
     patch_schedule_get_event = patch.object(
         SaltEvent, "get_event", return_value={"complete": True, "schedule": {}}
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
 
-    with (
-        patch_makedirs
-    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_connect_pub, patch_schedule_get_event:
         assert schedule.delete("job1") == {
             "comment": "Job job1 does not exist.",
             "changes": {},
@@ -256,11 +261,14 @@ def test_add():
     patch_schedule_event_fire = patch.dict(
         schedule.__salt__, {"event.fire": MagicMock(return_value=True)}
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
     patch_schedule_get_event = patch.object(
         SaltEvent, "get_event", return_value={"complete": True, "schedule": {}}
     )
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_connect_pub, patch_schedule_event_fire:
 
         _ret_value = {"complete": True, "schedule": {"job1": {"salt": "salt"}}}
         patch_schedule_get_event = patch.object(
@@ -338,15 +346,16 @@ def test_run_job(job1):
     patch_schedule_event_fire = patch.dict(
         schedule.__salt__, {"event.fire": MagicMock(return_value=True)}
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
     patch_schedule_get_event = patch.object(
         SaltEvent,
         "get_event",
         return_value={"complete": True, "schedule": {"job1": job1}},
     )
 
-    with (
-        patch_makedirs
-    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_connect_pub, patch_schedule_get_event:
         assert schedule.run_job("job1") == {
             "comment": "Scheduling Job job1 on minion.",
             "result": True,
@@ -371,10 +380,11 @@ def test_enable_job():
     patch_schedule_get_event = patch.object(
         SaltEvent, "get_event", return_value={"complete": True, "schedule": {}}
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
 
-    with (
-        patch_makedirs
-    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_connect_pub, patch_schedule_get_event:
         assert schedule.enable_job("job1") == {
             "comment": "Job job1 does not exist.",
             "changes": {},
@@ -400,10 +410,11 @@ def test_disable_job():
     patch_schedule_get_event = patch.object(
         SaltEvent, "get_event", return_value={"complete": True, "schedule": {}}
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
 
-    with (
-        patch_makedirs
-    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_connect_pub, patch_schedule_get_event:
         assert schedule.disable_job("job1") == {
             "comment": "Job job1 does not exist.",
             "changes": {},
@@ -420,16 +431,20 @@ def test_save():
     Test if it save all scheduled jobs on the minion.
     """
     comm1 = "Schedule (non-pillar items) saved."
-    with patch.dict(
-        schedule.__opts__,
-        {"default_include": "/tmp"},
-    ):
-        with patch("os.makedirs", MagicMock(return_value=True)):
-            mock = MagicMock(return_value=True)
-            with patch.dict(schedule.__salt__, {"event.fire": mock}):
-                _ret_value = {"complete": True, "schedule": {}}
-                with patch.object(SaltEvent, "get_event", return_value=_ret_value):
-                    assert schedule.save() == {"comment": comm1, "result": True}
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
+    with patch_schedule_connect_pub:
+        with patch.dict(
+            schedule.__opts__,
+            {"default_include": "/tmp"},
+        ):
+            with patch("os.makedirs", MagicMock(return_value=True)):
+                mock = MagicMock(return_value=True)
+                with patch.dict(schedule.__salt__, {"event.fire": mock}):
+                    _ret_value = {"complete": True, "schedule": {}}
+                    with patch.object(SaltEvent, "get_event", return_value=_ret_value):
+                        assert schedule.save() == {"comment": comm1, "result": True}
 
 
 # 'enable' function tests: 1
@@ -479,15 +494,16 @@ def test_move(job1):
     patch_schedule_event_fire = patch.dict(
         schedule.__salt__, {"event.fire": MagicMock(return_value=True)}
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
     patch_schedule_get_event = patch.object(
         SaltEvent,
         "get_event",
         return_value={"complete": True, "schedule": {"job1": job1}},
     )
 
-    with (
-        patch_makedirs
-    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_connect_pub, patch_schedule_get_event:
         mock = MagicMock(return_value={})
         patch_schedule_publish = patch.dict(
             schedule.__salt__, {"publish.publish": mock}
@@ -529,9 +545,7 @@ def test_move(job1):
 
         mock = MagicMock(side_effect=[{}, {"job1": {}}])
 
-    with (
-        patch_makedirs
-    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_connect_pub, patch_schedule_get_event:
         with patch.dict(schedule.__pillar__, {"schedule": {"job1": job1}}):
             mock = MagicMock(return_value={})
             patch_schedule_publish = patch.dict(
@@ -590,10 +604,11 @@ def test_copy(job1):
         "get_event",
         return_value={"complete": True, "schedule": {"job1": job1}},
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
 
-    with (
-        patch_makedirs
-    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_connect_pub:
         mock = MagicMock(return_value={})
         patch_schedule_publish = patch.dict(
             schedule.__salt__, {"publish.publish": mock}
@@ -633,9 +648,7 @@ def test_copy(job1):
             "result": False,
         }
 
-    with (
-        patch_makedirs
-    ), patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_connect_pub:
         mock = MagicMock(return_value={})
         patch_schedule_publish = patch.dict(
             schedule.__salt__, {"publish.publish": mock}
@@ -700,8 +713,8 @@ def test_modify(job1):
     comm1 = "Modified job: job1 in schedule."
     changes1 = {
         "job1": {
-            "new": OrderedDict(new_job1),
-            "old": OrderedDict(current_job1),
+            "new": salt.utils.odict.OrderedDict(new_job1),
+            "old": salt.utils.odict.OrderedDict(current_job1),
         }
     }
 
@@ -716,8 +729,8 @@ def test_modify(job1):
 
     changes4 = {
         "job1": {
-            "new": OrderedDict(new_job4),
-            "old": OrderedDict(current_job1),
+            "new": salt.utils.odict.OrderedDict(new_job4),
+            "old": salt.utils.odict.OrderedDict(current_job1),
         }
     }
 
@@ -745,8 +758,11 @@ def test_modify(job1):
     patch_schedule_event_fire = patch.dict(
         schedule.__salt__, {"event.fire": MagicMock(return_value=True)}
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
 
-    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_event_fire, patch_schedule_connect_pub:
 
         _ret_value = {"complete": True, "schedule": {"job1": current_job1}}
         patch_schedule_get_event = patch.object(
@@ -900,15 +916,16 @@ def test_is_enabled():
         schedule.__salt__,
         {"event.fire": MagicMock(return_value=True), "schedule.list": mock_lst},
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
     patch_schedule_get_event = patch.object(
         SaltEvent,
         "get_event",
         return_value={"complete": True, "schedule": {"job1": job1}},
     )
 
-    with (
-        patch_makedirs
-    ), patch_schedule_opts, patch_schedule_get_event, patch_schedule_salt:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_get_event, patch_schedule_connect_pub, patch_schedule_salt:
         ret = schedule.is_enabled("job1")
         assert ret == job1
 
@@ -945,10 +962,11 @@ def test_job_status():
     patch_schedule_get_event = patch.object(
         SaltEvent, "get_event", return_value={"complete": True, "data": job1}
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
 
-    with (
-        patch_makedirs
-    ), patch_schedule_opts, patch_schedule_get_event, patch_schedule_salt:
+    with patch_makedirs, patch_schedule_opts, patch_schedule_get_event, patch_schedule_connect_pub, patch_schedule_salt:
         ret = schedule.job_status("job1")
         assert ret == {
             "_last_run": "2021-11-01T12:36:57",
@@ -997,15 +1015,14 @@ def test_list(job1):
     patch_schedule_get_event = patch.object(
         SaltEvent, "get_event", return_value=_ret_value
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
     patch_schedule_os_path_exists = patch(
         "os.path.exists", MagicMock(return_value=True)
     )
 
-    with (
-        patch_schedule_opts
-    ), (
-        patch_schedule_event_fire
-    ), patch_schedule_get_event, patch_schedule_os_path_exists, patch_makedirs:
+    with patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_connect_pub, patch_schedule_os_path_exists, patch_makedirs:
         with patch(
             "salt.utils.files.fopen", mock_open(read_data=saved_schedule)
         ) as fopen_mock:
@@ -1033,13 +1050,7 @@ def test_list(job1):
     seconds: 10
 """
 
-    with (
-        patch_schedule_opts
-    ), (
-        patch_makedirs
-    ), (
-        patch_schedule_event_fire
-    ), patch_schedule_get_event, patch_schedule_os_path_exists:
+    with patch_schedule_opts, patch_makedirs, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_connect_pub, patch_schedule_os_path_exists:
         with patch("salt.utils.files.fopen", mock_open(read_data="")) as fopen_mock:
             ret = schedule.list_()
             assert ret == expected
@@ -1071,11 +1082,7 @@ def test_list(job1):
     seconds: 10
 """
 
-    with (
-        patch_schedule_opts
-    ), (
-        patch_schedule_event_fire
-    ), patch_schedule_get_event, patch_schedule_os_path_exists, patch_makedirs:
+    with patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_connect_pub, patch_schedule_os_path_exists, patch_makedirs:
         with patch(
             "salt.utils.files.fopen", mock_open(read_data=saved_schedule)
         ) as fopen_mock:
@@ -1127,15 +1134,14 @@ def test_list_global_enabled(job1):
     patch_schedule_get_event = patch.object(
         SaltEvent, "get_event", return_value=_ret_value
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
     patch_schedule_os_path_exists = patch(
         "os.path.exists", MagicMock(return_value=True)
     )
 
-    with (
-        patch_schedule_opts
-    ), (
-        patch_schedule_event_fire
-    ), patch_schedule_get_event, patch_schedule_os_path_exists, patch_makedirs:
+    with patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_connect_pub, patch_schedule_os_path_exists, patch_makedirs:
         with patch(
             "salt.utils.files.fopen", mock_open(read_data=saved_schedule)
         ) as fopen_mock:
@@ -1188,15 +1194,14 @@ def test_list_global_disabled(job1):
     patch_schedule_get_event = patch.object(
         SaltEvent, "get_event", return_value=_ret_value
     )
+    patch_schedule_connect_pub = patch.object(
+        SaltEvent, "connect_pub", return_value=True
+    )
     patch_schedule_os_path_exists = patch(
         "os.path.exists", MagicMock(return_value=True)
     )
 
-    with (
-        patch_schedule_opts
-    ), (
-        patch_schedule_event_fire
-    ), patch_schedule_get_event, patch_schedule_os_path_exists, patch_makedirs:
+    with patch_schedule_opts, patch_schedule_event_fire, patch_schedule_get_event, patch_schedule_connect_pub, patch_schedule_os_path_exists, patch_makedirs:
         with patch(
             "salt.utils.files.fopen", mock_open(read_data=saved_schedule)
         ) as fopen_mock:
