@@ -1,12 +1,10 @@
 """
 Tests for the win_pkg module
 """
-
 import logging
 
 import pytest
 
-import salt.loader.dunder
 import salt.modules.config as config
 import salt.modules.cp as cp
 import salt.modules.pkg_resource as pkg_resource
@@ -58,7 +56,7 @@ def configure_loader_modules(minion_opts):
     opts = minion_opts
     opts["master_uri"] = "localhost"
     return {
-        cp: {"__opts__": salt.loader.dunder.__opts__.with_default(opts)},
+        cp: {"__opts__": opts},
         win_pkg: {
             "_get_latest_package_version": MagicMock(return_value="3.03"),
             "_get_package_info": MagicMock(return_value=pkg_info),
@@ -193,29 +191,6 @@ def test_pkg_install_existing():
         assert expected == result
 
 
-def test_pkg_install_existing_force_true():
-    """
-    test pkg.install when the package is already installed
-    and force=True
-    """
-    ret_reg = {"Nullsoft Install System": "3.03"}
-    # The 2nd time it's run, pkg.list_pkgs uses with stringify
-    se_list_pkgs = {"nsis": ["3.03"]}
-    with patch.object(win_pkg, "list_pkgs", return_value=se_list_pkgs), patch.object(
-        win_pkg, "_get_reg_software", return_value=ret_reg
-    ), patch.dict(
-        win_pkg.__salt__,
-        {
-            "cmd.run_all": MagicMock(return_value={"retcode": 0}),
-            "cp.cache_file": MagicMock(return_value="C:\\fake\\path.exe"),
-            "cp.is_cached": MagicMock(return_value=True),
-        },
-    ):
-        expected = {"nsis": {"install status": "success"}}
-        result = win_pkg.install(name="nsis", force=True)
-        assert expected == result
-
-
 def test_pkg_install_latest():
     """
     test pkg.install when the package is already installed
@@ -452,11 +427,10 @@ def test_pkg_install_log_message(caplog):
             version="3.03",
             extra_install_flags="-e True -test_flag True",
         )
-        for x in caplog.messages:
-            print(x)
-        assert 'PKG : cmd: "runme.exe" /s -e True -test_flag True'.lower() in [
-            x.lower() for x in caplog.messages
-        ]
+        assert (
+            'PKG : cmd: C:\\WINDOWS\\system32\\cmd.exe /c "runme.exe" /s -e '
+            "True -test_flag True"
+        ).lower() in [x.lower() for x in caplog.messages]
         assert "PKG : pwd: ".lower() in [x.lower() for x in caplog.messages]
         assert "PKG : retcode: 0" in caplog.messages
 
@@ -674,9 +648,9 @@ def test_pkg_remove_log_message(caplog):
         win_pkg.remove(
             pkgs=["firebox"],
         )
-        assert 'PKG : cmd: "%program.exe" /S'.lower() in [
-            x.lower() for x in caplog.messages
-        ]
+        assert (
+            'PKG : cmd: C:\\WINDOWS\\system32\\cmd.exe /c "%program.exe" /S'
+        ).lower() in [x.lower() for x in caplog.messages]
         assert "PKG : pwd: ".lower() in [x.lower() for x in caplog.messages]
         assert "PKG : retcode: 0" in caplog.messages
 
@@ -780,21 +754,3 @@ def test__reverse_cmp_pkg_versions(v1, v2, expected):
     assert result == expected, "cmp({}, {}) should be {}, got {}".format(
         v1, v2, expected, result
     )
-
-
-def test__repo_process_pkg_sls():
-    patch_render = patch("salt.loader.render")
-    patch_opts = patch.dict(win_pkg.__opts__, {"renderer": None})
-    patch_compile = patch("salt.template.compile_template", return_value="junk")
-    with patch_opts, patch_render as render, patch_compile as test:
-        ret = win_pkg._repo_process_pkg_sls(
-            filename="junk",
-            short_path_name="junk",
-            ret={},
-            successful_verbose=False,
-            saltenv="spongebob",
-        )
-        assert ret is False
-        test.assert_called_once_with(
-            "junk", render(), None, "", "", saltenv="spongebob"
-        )
