@@ -1,15 +1,12 @@
 import copy
 import logging
 import os
-import signal
-import time
-import uuid
 
 import pytest
+import tornado
+import tornado.gen
+import tornado.testing
 
-import salt.ext.tornado
-import salt.ext.tornado.gen
-import salt.ext.tornado.testing
 import salt.minion
 import salt.modules.test as test_mod
 import salt.syspaths
@@ -39,7 +36,7 @@ def connect_master_mock():
             self.calls = 0
             self.exc = Exception
 
-        @salt.ext.tornado.gen.coroutine
+        @tornado.gen.coroutine
         def __call__(self, *args, **kwargs):
             self.calls += 1
             if self.calls == 1:
@@ -57,8 +54,11 @@ def test_minion_load_grains_false(minion_opts):
     minion_opts["grains"] = {"foo": "bar"}
     with patch("salt.loader.grains") as grainsfunc:
         minion = salt.minion.Minion(minion_opts, load_grains=False)
-        assert minion.opts["grains"] == minion_opts["grains"]
-        grainsfunc.assert_not_called()
+        try:
+            assert minion.opts["grains"] == minion_opts["grains"]
+            grainsfunc.assert_not_called()
+        finally:
+            minion.destroy()
 
 
 def test_minion_load_grains_true(minion_opts):
@@ -67,8 +67,11 @@ def test_minion_load_grains_true(minion_opts):
     """
     with patch("salt.loader.grains") as grainsfunc:
         minion = salt.minion.Minion(minion_opts, load_grains=True)
-        assert minion.opts["grains"] != {}
-        grainsfunc.assert_called()
+        try:
+            assert minion.opts["grains"] != {}
+            grainsfunc.assert_called()
+        finally:
+            minion.destroy()
 
 
 def test_minion_load_grains_default(minion_opts):
@@ -77,8 +80,11 @@ def test_minion_load_grains_default(minion_opts):
     """
     with patch("salt.loader.grains") as grainsfunc:
         minion = salt.minion.Minion(minion_opts)
-        assert minion.opts["grains"] != {}
-        grainsfunc.assert_called()
+        try:
+            assert minion.opts["grains"] != {}
+            grainsfunc.assert_called()
+        finally:
+            minion.destroy()
 
 
 @pytest.mark.parametrize(
@@ -90,69 +96,71 @@ def test_minion_load_grains_default(minion_opts):
         ),
         (
             "fire_event_async",
-            lambda data, tag, cb=None, timeout=60: salt.ext.tornado.gen.maybe_future(
-                True
-            ),
+            lambda data, tag, cb=None, timeout=60: tornado.gen.maybe_future(True),
         ),
     ],
 )
 def test_send_req_fires_completion_event(event, minion_opts):
-    req_id = uuid.uuid4()
     event_enter = MagicMock()
     event_enter.send.side_effect = event[1]
     event = MagicMock()
     event.__enter__.return_value = event_enter
 
-    with patch("salt.utils.event.get_event", return_value=event), patch(
-        "uuid.uuid4", return_value=req_id
-    ):
+    with patch("salt.utils.event.get_event", return_value=event):
         minion_opts["random_startup_delay"] = 0
         minion_opts["return_retry_tries"] = 30
         minion_opts["grains"] = {}
         with patch("salt.loader.grains"):
             minion = salt.minion.Minion(minion_opts)
 
-            load = {"load": "value"}
-            timeout = 60
+            try:
+                load = {"load": "value"}
+                timeout = 60
 
-            # XXX This is buggy because "async" in event[0] will never evaluate
-            # to True and if it *did* evaluate to true the test would fail
-            # because you Mock isn't a co-routine.
-            if "async" in event[0]:
-                rtn = minion._send_req_async(load, timeout).result()
-            else:
-                rtn = minion._send_req_sync(load, timeout)
+                # XXX This is buggy because "async" in event[0] will never evaluate
+                # to True and if it *did* evaluate to true the test would fail
+                # because you Mock isn't a co-routine.
+                if "async" in event[0]:
+                    rtn = minion._send_req_async(load, timeout).result()
+                else:
+                    rtn = minion._send_req_sync(load, timeout)
 
-            # get the
-            for idx, call in enumerate(event.mock_calls, 1):
-                if "fire_event" in call[0]:
-                    condition_event_tag = (
-                        len(call.args) > 1
-                        and call.args[1]
-                        == f"__master_req_channel_payload/{req_id}/{minion_opts['master']}"
-                    )
-                    condition_event_tag_error = "{} != {}; Call(number={}): {}".format(
-                        idx, call, call.args[1], "__master_req_channel_payload"
-                    )
-                    condition_timeout = (
-                        len(call.kwargs) == 1 and call.kwargs["timeout"] == timeout
-                    )
-                    condition_timeout_error = "{} != {}; Call(number={}): {}".format(
-                        idx, call, call.kwargs["timeout"], timeout
-                    )
+                # get the
+                for idx, call in enumerate(event.mock_calls, 1):
+                    if "fire_event" in call[0]:
+                        condition_event_tag = (
+                            len(call.args) > 1
+                            and call.args[1]
+                            == f"__master_req_channel_payload/{minion_opts['master']}"
+                        )
+                        condition_event_tag_error = (
+                            "{} != {}; Call(number={}): {}".format(
+                                idx, call, call.args[1], "__master_req_channel_payload"
+                            )
+                        )
+                        condition_timeout = (
+                            len(call.kwargs) == 1 and call.kwargs["timeout"] == timeout
+                        )
+                        condition_timeout_error = (
+                            "{} != {}; Call(number={}): {}".format(
+                                idx, call, call.kwargs["timeout"], timeout
+                            )
+                        )
 
-                    fire_event_called = True
-                    assert condition_event_tag, condition_event_tag_error
-                    assert condition_timeout, condition_timeout_error
+                        fire_event_called = True
+                        assert condition_event_tag, condition_event_tag_error
+                        assert condition_timeout, condition_timeout_error
 
-            assert fire_event_called
-            assert rtn
+                assert fire_event_called
+                assert rtn
+            finally:
+                minion.destroy()
 
 
 async def test_send_req_async_regression_62453(minion_opts):
     event_enter = MagicMock()
     event_enter.send.side_effect = (
-        lambda data, tag, cb=None, timeout=60: salt.ext.tornado.gen.maybe_future(True)
+        lambda data, tag, cb=None, timeout=60: tornado.gen.maybe_future(True)
     )
     event = MagicMock()
     event.__enter__.return_value = event_enter
@@ -160,15 +168,16 @@ async def test_send_req_async_regression_62453(minion_opts):
     minion_opts["random_startup_delay"] = 0
     minion_opts["return_retry_tries"] = 30
     minion_opts["grains"] = {}
+    minion_opts["ipc_mode"] = "tcp"
     with patch("salt.loader.grains"):
         minion = salt.minion.Minion(minion_opts)
 
         load = {"load": "value"}
-        timeout = 1
+        timeout = 60
 
         # We are just validating no exception is raised
-        with pytest.raises(TimeoutError):
-            rtn = await minion._send_req_async(load, timeout)
+        rtn = await minion._send_req_async(load, timeout)
+        assert rtn is False
 
 
 def test_mine_send_tries(minion_opts):
@@ -343,7 +352,7 @@ def test_handle_decoded_payload_jid_match_in_jid_queue(minion_opts):
     minion = salt.minion.Minion(
         minion_opts,
         jid_queue=copy.copy(mock_jid_queue),
-        io_loop=salt.ext.tornado.ioloop.IOLoop(),
+        io_loop=tornado.ioloop.IOLoop(),
     )
     try:
         ret = minion._handle_decoded_payload(mock_data).result()
@@ -372,7 +381,7 @@ def test_handle_decoded_payload_jid_queue_addition(minion_opts):
         minion = salt.minion.Minion(
             minion_opts,
             jid_queue=copy.copy(mock_jid_queue),
-            io_loop=salt.ext.tornado.ioloop.IOLoop(),
+            io_loop=tornado.ioloop.IOLoop(),
         )
         try:
 
@@ -409,7 +418,7 @@ def test_handle_decoded_payload_jid_queue_reduced_minion_jid_queue_hwm(minion_op
         minion = salt.minion.Minion(
             minion_opts,
             jid_queue=copy.copy(mock_jid_queue),
-            io_loop=salt.ext.tornado.ioloop.IOLoop(),
+            io_loop=tornado.ioloop.IOLoop(),
         )
         try:
 
@@ -441,15 +450,15 @@ def test_process_count_max(minion_opts):
     ), patch(
         "salt.utils.minion.running", MagicMock(return_value=[])
     ), patch(
-        "salt.ext.tornado.gen.sleep",
-        MagicMock(return_value=salt.ext.tornado.concurrent.Future()),
+        "tornado.gen.sleep",
+        MagicMock(return_value=tornado.concurrent.Future()),
     ):
         process_count_max = 10
         minion_opts["__role"] = "minion"
         minion_opts["minion_jid_queue_hwm"] = 100
         minion_opts["process_count_max"] = process_count_max
 
-        io_loop = salt.ext.tornado.ioloop.IOLoop()
+        io_loop = tornado.ioloop.IOLoop()
         minion = salt.minion.Minion(minion_opts, jid_queue=[], io_loop=io_loop)
         try:
 
@@ -457,9 +466,7 @@ def test_process_count_max(minion_opts):
             class SleepCalledException(Exception):
                 """Thrown when sleep is called"""
 
-            salt.ext.tornado.gen.sleep.return_value.set_exception(
-                SleepCalledException()
-            )
+            tornado.gen.sleep.return_value.set_exception(SleepCalledException())
 
             # up until process_count_max: gen.sleep does not get called, processes are started normally
             for i in range(process_count_max):
@@ -492,7 +499,7 @@ def test_process_count_max(minion_opts):
 
 
 @pytest.mark.slow_test
-async def test_beacons_before_connect(minion_opts):
+def test_beacons_before_connect(minion_opts):
     """
     Tests that the 'beacons_before_connect' option causes the beacons to be initialized before connect.
     """
@@ -507,13 +514,12 @@ async def test_beacons_before_connect(minion_opts):
         MagicMock(return_value=True),
     ):
         minion_opts["beacons_before_connect"] = True
-        io_loop = salt.ext.tornado.ioloop.IOLoop()
-        io_loop.make_current()
+        io_loop = tornado.ioloop.IOLoop()
         minion = salt.minion.Minion(minion_opts, io_loop=io_loop)
         try:
 
             try:
-                await minion.tune_in(start=True)
+                minion.tune_in(start=True)
             except RuntimeError:
                 pass
 
@@ -525,7 +531,7 @@ async def test_beacons_before_connect(minion_opts):
 
 
 @pytest.mark.slow_test
-async def test_scheduler_before_connect(minion_opts):
+def test_scheduler_before_connect(minion_opts):
     """
     Tests that the 'scheduler_before_connect' option causes the scheduler to be initialized before connect.
     """
@@ -540,12 +546,11 @@ async def test_scheduler_before_connect(minion_opts):
         MagicMock(return_value=True),
     ):
         minion_opts["scheduler_before_connect"] = True
-        io_loop = salt.ext.tornado.ioloop.IOLoop()
-        io_loop.make_current()
+        io_loop = tornado.ioloop.IOLoop()
         minion = salt.minion.Minion(minion_opts, io_loop=io_loop)
         try:
             try:
-                await minion.tune_in(start=True)
+                minion.tune_in(start=True)
             except RuntimeError:
                 pass
 
@@ -571,7 +576,7 @@ def test_minion_module_refresh(minion_opts):
         try:
             minion = salt.minion.Minion(
                 minion_opts,
-                io_loop=salt.ext.tornado.ioloop.IOLoop(),
+                io_loop=tornado.ioloop.IOLoop(),
             )
             minion.schedule = salt.utils.schedule.Schedule(
                 minion_opts, {}, returners={}
@@ -599,7 +604,7 @@ def test_minion_module_refresh_beacons_refresh(minion_opts):
         try:
             minion = salt.minion.Minion(
                 minion_opts,
-                io_loop=salt.ext.tornado.ioloop.IOLoop(),
+                io_loop=tornado.ioloop.IOLoop(),
             )
             minion.schedule = salt.utils.schedule.Schedule(
                 minion_opts, {}, returners={}
@@ -615,7 +620,7 @@ def test_minion_module_refresh_beacons_refresh(minion_opts):
 
 
 @pytest.mark.slow_test
-async def test_when_ping_interval_is_set_the_callback_should_be_added_to_periodic_callbacks(
+def test_when_ping_interval_is_set_the_callback_should_be_added_to_periodic_callbacks(
     minion_opts,
 ):
     with patch("salt.minion.Minion.ctx", MagicMock(return_value={})), patch(
@@ -629,8 +634,7 @@ async def test_when_ping_interval_is_set_the_callback_should_be_added_to_periodi
         MagicMock(return_value=True),
     ):
         minion_opts["ping_interval"] = 10
-        io_loop = salt.ext.tornado.ioloop.IOLoop()
-        io_loop.make_current()
+        io_loop = tornado.ioloop.IOLoop()
         minion = salt.minion.Minion(minion_opts, io_loop=io_loop)
         try:
             try:
@@ -651,8 +655,7 @@ def test_when_passed_start_event_grains(minion_opts):
     # provide mock opts an os grain since we'll look for it later.
     minion_opts["grains"]["os"] = "linux"
     minion_opts["start_event_grains"] = ["os"]
-    io_loop = salt.ext.tornado.ioloop.IOLoop()
-    io_loop.make_current()
+    io_loop = tornado.ioloop.IOLoop()
     minion = salt.minion.Minion(minion_opts, io_loop=io_loop)
     try:
         minion.tok = MagicMock()
@@ -670,8 +673,7 @@ def test_when_passed_start_event_grains(minion_opts):
 
 @pytest.mark.slow_test
 def test_when_not_passed_start_event_grains(minion_opts):
-    io_loop = salt.ext.tornado.ioloop.IOLoop()
-    io_loop.make_current()
+    io_loop = tornado.ioloop.IOLoop()
     minion = salt.minion.Minion(minion_opts, io_loop=io_loop)
     try:
         minion.tok = MagicMock()
@@ -687,8 +689,7 @@ def test_when_not_passed_start_event_grains(minion_opts):
 @pytest.mark.slow_test
 def test_when_other_events_fired_and_start_event_grains_are_set(minion_opts):
     minion_opts["start_event_grains"] = ["os"]
-    io_loop = salt.ext.tornado.ioloop.IOLoop()
-    io_loop.make_current()
+    io_loop = tornado.ioloop.IOLoop()
     minion = salt.minion.Minion(minion_opts, io_loop=io_loop)
     try:
         minion.tok = MagicMock()
@@ -725,8 +726,7 @@ def test_gen_modules_executors(minion_opts):
     """
     Ensure gen_modules is called with the correct arguments #54429
     """
-    io_loop = salt.ext.tornado.ioloop.IOLoop()
-    io_loop.make_current()
+    io_loop = tornado.ioloop.IOLoop()
     minion = salt.minion.Minion(minion_opts, io_loop=io_loop)
 
     class MockPillarCompiler:
@@ -744,6 +744,38 @@ def test_gen_modules_executors(minion_opts):
         minion.destroy()
 
 
+def test_reinit_crypto_on_fork(minion_opts):
+    """
+    Ensure salt.utils.crypt.reinit_crypto() is executed when forking for new job
+    """
+    minion_opts["multiprocessing"] = True
+    with patch("salt.utils.process.default_signals"):
+
+        io_loop = tornado.ioloop.IOLoop()
+        minion = salt.minion.Minion(minion_opts, io_loop=io_loop)
+
+        job_data = {"jid": "test-jid", "fun": "test.ping"}
+
+        def mock_start(self):
+            # pylint: disable=comparison-with-callable
+            assert (
+                len(
+                    [
+                        x
+                        for x in self._after_fork_methods
+                        if x[0] == salt.utils.crypt.reinit_crypto
+                    ]
+                )
+                == 1
+            )
+            # pylint: enable=comparison-with-callable
+
+        with patch.object(
+            salt.utils.process.SignalHandlingProcess, "start", mock_start
+        ):
+            io_loop.run_sync(lambda: minion._handle_decoded_payload(job_data))
+
+
 def test_minion_manage_schedule(minion_opts):
     """
     Tests that the manage_schedule will call the add function, adding
@@ -759,8 +791,7 @@ def test_minion_manage_schedule(minion_opts):
         "salt.utils.process.SignalHandlingProcess.join",
         MagicMock(return_value=True),
     ):
-        io_loop = salt.ext.tornado.ioloop.IOLoop()
-        io_loop.make_current()
+        io_loop = tornado.ioloop.IOLoop()
 
         with patch("salt.utils.schedule.clean_proc_dir", MagicMock(return_value=None)):
             try:
@@ -819,8 +850,7 @@ def test_minion_manage_beacons(minion_opts):
         try:
             minion_opts["beacons"] = {}
 
-            io_loop = salt.ext.tornado.ioloop.IOLoop()
-            io_loop.make_current()
+            io_loop = MagicMock()
 
             mock_functions = {"test.ping": None}
             minion = salt.minion.Minion(minion_opts, io_loop=io_loop)
@@ -963,6 +993,8 @@ async def test_master_type_failover_no_masters(minion_opts):
     ):
         with pytest.raises(SaltClientError):
             minion = salt.minion.Minion(minion_opts)
+            # Mock the io_loop so calls to stop/close won't happen.
+            minion.io_loop = MagicMock()
             await minion.connect_master()
 
 
@@ -987,7 +1019,7 @@ def test_minion_grains_refresh_pre_exec_false(minion_opts):
         minion = salt.minion.Minion(
             minion_opts,
             jid_queue=None,
-            io_loop=salt.ext.tornado.ioloop.IOLoop(),
+            io_loop=tornado.ioloop.IOLoop(),
             load_grains=False,
         )
         try:
@@ -1010,7 +1042,7 @@ def test_minion_grains_refresh_pre_exec_true(minion_opts):
         minion = salt.minion.Minion(
             minion_opts,
             jid_queue=None,
-            io_loop=salt.ext.tornado.ioloop.IOLoop(),
+            io_loop=tornado.ioloop.IOLoop(),
             load_grains=False,
         )
         try:
@@ -1082,7 +1114,7 @@ async def test_master_type_disable(minion_opts):
 
         try:
             minion_man = salt.minion.MinionManager(minion_opts)
-            minion_man._connect_minion(minion)
+            await minion_man._connect_minion(minion)
         except RuntimeError:
             pytest.fail("_connect_minion(minion) threw an error, This was not expected")
 
@@ -1091,6 +1123,8 @@ async def test_master_type_disable(minion_opts):
         assert "schedule" in minion.periodic_callbacks
         assert minion.connected is False
     finally:
+        # Mock the io_loop so calls to stop/close won't happen.
+        minion.io_loop = MagicMock()
         minion.destroy()
 
 
@@ -1147,7 +1181,7 @@ async def test_connect_master_unresolveable_error(minion_opts, connect_master_mo
     connect_master_mock.exc = SaltMasterUnresolvableError
     minion.connect_master = connect_master_mock
     minion.destroy = MagicMock()
-    mm._connect_minion(minion)
+    await mm._connect_minion(minion)
     minion.destroy.assert_called_once()
 
     # Unresolvable errors break out of the loop.
@@ -1160,68 +1194,12 @@ async def test_connect_master_general_exception_error(minion_opts, connect_maste
     """
     mm = salt.minion.MinionManager(minion_opts)
     minion = salt.minion.Minion(minion_opts)
-    connect_master_mock.exc = Exception
+    connect_master_mock.exc = SaltClientError
     minion.connect_master = connect_master_mock
     minion.destroy = MagicMock()
-    mm._connect_minion(minion)
+    await mm._connect_minion(minion)
     minion.destroy.assert_called_once()
 
     # The first call raised an error which caused minion.destroy to get called,
     # the second call is a success.
     assert minion.connect_master.calls == 2
-
-
-async def test_minion_manager_async_stop(io_loop, minion_opts, tmp_path):
-    """
-    Ensure MinionManager's stop method works correctly and calls the
-    stop_async method
-    """
-
-    # Setup sock_dir with short path
-    minion_opts["sock_dir"] = str(tmp_path / "sock")
-
-    # Create a MinionManager instance with a mock minion
-    mm = salt.minion.MinionManager(minion_opts)
-    minion = MagicMock(name="minion")
-    parent_signal_handler = MagicMock(name="parent_signal_handler")
-    mm.minions.append(minion)
-
-    # Set up event publisher and event
-    mm._bind()
-    assert mm.event_publisher is not None
-    assert mm.event is not None
-
-    # Check io_loop is running
-    assert mm.io_loop._running
-
-    # Set up values for event to send
-    load = {"key": "value"}
-    ret = {}
-
-    # Connect to minion event bus
-    with salt.utils.event.get_event("minion", opts=minion_opts, listen=True) as event:
-
-        # call stop to start stopping the minion
-        # mm.stop(signal.SIGTERM, parent_signal_handler)
-        mm.stop(signal.SIGTERM, parent_signal_handler)
-
-        # Fire an event and ensure we can still read it back while the minion
-        # is stopping
-        await event.fire_event_async(load, "test_event", timeout=1)
-        start = time.time()
-        while time.time() - start < 5:
-            ret = event.get_event(tag="test_event", wait=0.3)
-            if ret:
-                break
-            await salt.ext.tornado.gen.sleep(0.3)
-    assert "key" in ret
-    assert ret["key"] == "value"
-
-    # Sleep to allow stop_async to complete
-    await salt.ext.tornado.gen.sleep(5)
-
-    # Ensure stop_async has been called
-    minion.destroy.assert_called_once()
-    parent_signal_handler.assert_called_once_with(signal.SIGTERM, None)
-    assert mm.event_publisher is None
-    assert mm.event is None
