@@ -4,7 +4,6 @@ tests.pytests.unit.test_version
 
 Test salt's regex git describe version parsing
 """
-
 import re
 
 import pytest
@@ -73,7 +72,7 @@ def test_version_parsing(version_string, full_info, version):
             .replace("-", "+", 1)
             .replace("-", ".", 1)
         )
-    assert version in saltstack_version.string
+    assert saltstack_version.string == version
 
 
 @pytest.mark.parametrize(
@@ -159,7 +158,9 @@ def test_version_report_lines():
     line_lengths = {
         len(line.split(":")[0])
         for line in versions_report_ret[start_looking_index:]
-        if line != " " and line not in ("System Versions:", "Salt Extensions:")
+        if line != " "
+        and line
+        not in ("System Versions:", "Salt Extensions:", "Salt Package Information:")
     }
     # Check that they are all the same size (only one element in the set)
     assert len(line_lengths) == 1
