@@ -1,4 +1,4 @@
-import urllib
+import sys
 
 import pytest
 import requests
@@ -154,7 +154,10 @@ def test_query_null_response():
 
     url = f"http://{host}:{port}/"
     result = http.query(url, raise_error=False)
-    assert result == {"body": None}, result
+    if sys.platform.startswith("win"):
+        assert result == {"error": "[Errno 10061] Unknown error"}, result
+    else:
+        assert result == {"error": "[Errno 111] Connection refused"}
 
 
 def test_query_error_handling():
@@ -311,27 +314,3 @@ def test_backends_decode_body_true(httpserver, backend):
     )
     body = ret.get("body", "")
     assert isinstance(body, str)
-
-
-def test_requests_post_content_type(httpserver):
-    url = httpserver.url_for("/post-content-type")
-    data = urllib.parse.urlencode({"payload": "test"})
-    opts = {
-        "proxy_host": "127.0.0.1",
-        "proxy_port": 88,
-    }
-    with patch("requests.Session") as mock_session:
-        sess = MagicMock()
-        sess.headers = {}
-        mock_session.return_value = sess
-        ret = http.query(
-            url,
-            method="POST",
-            data=data,
-            backend="tornado",
-            opts=opts,
-        )
-        assert "Content-Type" in sess.headers
-        assert sess.headers["Content-Type"] == "application/x-www-form-urlencoded"
-        assert "Content-Length" in sess.headers
-        assert sess.headers["Content-Length"] == "12"
