@@ -4,11 +4,9 @@
 
     PyTest helpers functions
 """
-
 import logging
 import os
 import pathlib
-import pprint
 import shutil
 import subprocess
 import tempfile
@@ -19,7 +17,6 @@ import warnings
 from contextlib import contextmanager
 
 import attr
-import psutil
 import pytest
 import requests
 from saltfactories.utils import random_string
@@ -66,7 +63,7 @@ def temp_state_file(name, contents, saltenv="base", strip_first_newline=True):
         saltenv(str):
             The salt env to use. Either ``base`` or ``prod``
         strip_first_newline(bool):
-            Whether to strip the initial first new line char or not.
+            Wether to strip the initial first new line char or not.
     """
 
     if saltenv == "base":
@@ -112,7 +109,7 @@ def temp_pillar_file(name, contents, saltenv="base", strip_first_newline=True):
         saltenv(str):
             The salt env to use. Either ``base`` or ``prod``
         strip_first_newline(bool):
-            Whether to strip the initial first new line char or not.
+            Wether to strip the initial first new line char or not.
     """
 
     if saltenv == "base":
@@ -239,7 +236,7 @@ class TestGroup:
             self._delete_group = True
             log.debug("Created system group: %s", self)
         else:
-            log.debug("Reusing existing system group: %s", self)
+            log.debug("Reusing exising system group: %s", self)
         if self.members:
             ret = self.sminion.functions.group.members(
                 self.name, members_list=self.members
@@ -328,20 +325,14 @@ class TestAccount:
         if not self.sminion.functions.user.info(self.username):
             log.debug("Creating system account: %s", self)
             ret = self.sminion.functions.user.add(self.username)
-            assert ret is True
+            assert ret
             self._delete_account = True
-        if salt.utils.platform.is_windows():
-            log.debug("Configuring system account: %s", self)
-            ret = self.sminion.functions.user.update(
-                self.username, expired=False, password_never_expires=True
-            )
-            assert ret is True
         if salt.utils.platform.is_darwin() or salt.utils.platform.is_windows():
             password = self.password
         else:
             password = self.hashed_password
         ret = self.sminion.functions.shadow.set_password(self.username, password)
-        assert ret is True
+        assert ret
         assert self.username in self.sminion.functions.user.list_users()
         if self._group:
             self.group.__enter__()
@@ -353,7 +344,7 @@ class TestAccount:
         if self._delete_account:
             log.debug("Created system account: %s", self)
         else:
-            log.debug("Reusing existing system account: %s", self)
+            log.debug("Reusing exisintg system account: %s", self)
         # Run tests
         return self
 
@@ -514,8 +505,6 @@ class FakeSaltExtension:
             setup_requires =
               wheel
               setuptools>=50.3.2
-            install_requires =
-              distro
 
             [options.entry_points]
             salt.loader=
@@ -711,20 +700,16 @@ class EntropyGenerator:
         kernel_entropy_file = pathlib.Path("/proc/sys/kernel/random/entropy_avail")
         kernel_poolsize_file = pathlib.Path("/proc/sys/kernel/random/poolsize")
         if not kernel_entropy_file.exists():
-            log.info("The '%s' file is not available", kernel_entropy_file)
+            log.info("The '%s' file is not avilable", kernel_entropy_file)
             return
 
-        self.current_entropy = int(
-            kernel_entropy_file.read_text(encoding="utf-8").strip()
-        )
+        self.current_entropy = int(kernel_entropy_file.read_text().strip())
         log.info("Available Entropy: %s", self.current_entropy)
 
         if not kernel_poolsize_file.exists():
-            log.info("The '%s' file is not available", kernel_poolsize_file)
+            log.info("The '%s' file is not avilable", kernel_poolsize_file)
         else:
-            self.current_poolsize = int(
-                kernel_poolsize_file.read_text(encoding="utf-8").strip()
-            )
+            self.current_poolsize = int(kernel_poolsize_file.read_text().strip())
             log.info("Entropy Poolsize: %s", self.current_poolsize)
             # Account for smaller poolsizes using BLAKE2s
             if self.current_poolsize == 256:
@@ -750,9 +735,7 @@ class EntropyGenerator:
                         raise pytest.skip.Exception(message, _use_item_location=True)
                     raise pytest.fail(message)
                 subprocess.run([rngd, "-r", "/dev/urandom"], shell=False, check=True)
-                self.current_entropy = int(
-                    kernel_entropy_file.read_text(encoding="utf-8").strip()
-                )
+                self.current_entropy = int(kernel_entropy_file.read_text().strip())
                 log.info("Available Entropy: %s", self.current_entropy)
                 if self.current_entropy >= self.minimum_entropy:
                     break
@@ -787,9 +770,7 @@ class EntropyGenerator:
                     check=True,
                 )
                 os.unlink(target_file.name)
-                self.current_entropy = int(
-                    kernel_entropy_file.read_text(encoding="utf-8").strip()
-                )
+                self.current_entropy = int(kernel_entropy_file.read_text().strip())
                 log.info("Available Entropy: %s", self.current_entropy)
                 if self.current_entropy >= self.minimum_entropy:
                     break
@@ -829,65 +810,10 @@ def change_cwd(path):
         os.chdir(old_cwd)
 
 
-@contextmanager
-def reap_stray_processes(pid: int = os.getpid()):
-
-    try:
-        pre_children = psutil.Process(pid).children(recursive=True)
-        # Do stuff
-        yield
-    finally:
-        post_children = psutil.Process(pid).children(recursive=True)
-
-    children = []
-    for process in post_children:
-        if process in pre_children:
-            # Process existed before entering the context
-            continue
-        if not psutil.pid_exists(process.pid):
-            # Process just died
-            continue
-        # This process is alive and was not running before entering the context
-        children.append(process)
-
-    if not children:
-        log.info("No astray processes found")
-        return
-
-    def on_terminate(proc):
-        log.debug("Process %s terminated with exit code %s", proc, proc.returncode)
-
-    if children:
-        # Reverse the order, sublings first, parents after
-        children.reverse()
-        log.warning(
-            "Test suite left %d astray processes running. Killing those processes:\n%s",
-            len(children),
-            pprint.pformat(children),
-        )
-
-        _, alive = psutil.wait_procs(children, timeout=3, callback=on_terminate)
-        for child in alive:
-            try:
-                child.kill()
-            except psutil.NoSuchProcess:
-                continue
-
-        _, alive = psutil.wait_procs(alive, timeout=3, callback=on_terminate)
-        if alive:
-            # Give up
-            for child in alive:
-                log.warning(
-                    "Process %s survived SIGKILL, giving up:\n%s",
-                    child,
-                    pprint.pformat(child.as_dict()),
-                )
-
-
 @pytest.helpers.register
 def download_file(url, dest, auth=None):
     # NOTE the stream=True parameter below
-    with requests.get(url, stream=True, auth=auth, timeout=60) as r:
+    with requests.get(url, allow_redirects=True, stream=True, auth=auth) as r:
         r.raise_for_status()
         with salt.utils.files.fopen(dest, "wb") as f:
             for chunk in r.iter_content(chunk_size=8192):
