@@ -1,58 +1,53 @@
-# -*- coding: utf-8 -*-
-'''
+"""
     :codeauthor: Jayesh Kariya <jayeshk@saltstack.com>
-'''
+"""
 
-# Import Python Libs
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import Salt Testing Libs
-from tests.support.unit import TestCase
-from tests.support.mock import (
-    MagicMock,
-    patch,
-)
-
-# Import Salt Libs
 import salt.modules.memcached as memcached
 from salt.exceptions import CommandExecutionError, SaltInvocationError
-from salt.ext.six import integer_types
+from tests.support.mock import MagicMock, patch
+from tests.support.unit import TestCase
 
 
 class MemcachedTestCase(TestCase):
-    '''
+    """
     Test cases for salt.modules.memcached
-    '''
+    """
+
     # 'status' function tests: 2
 
     def test_status(self):
-        '''
+        """
         Test if it gets memcached status
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             @staticmethod
             def get_stats():
                 """
                 Mock of stats method
                 """
-                return [('127.0.0.1:11211 (1)', {})]
+                return [("127.0.0.1:11211 (1)", {})]
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
-            self.assertDictEqual(memcached.status(),
-                                 {'127.0.0.1:11211 (1)': {}})
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
+            self.assertDictEqual(memcached.status(), {"127.0.0.1:11211 (1)": {}})
 
     def test_status_false(self):
-        '''
+        """
         Test if it gets memcached status
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             @staticmethod
             def get_stats():
                 """
@@ -60,26 +55,29 @@ class MemcachedTestCase(TestCase):
                 """
                 return []
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
             self.assertFalse(memcached.status())
 
     # 'get' function tests: 1
 
     def test_get(self):
-        '''
+        """
         Test if it retrieve value for a key
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             @staticmethod
             def get_stats():
                 """
                 Mock of stats method
                 """
-                return [('127.0.0.1:11211 (1)', {})]
+                return [("127.0.0.1:11211 (1)", {})]
 
             @staticmethod
             def get(key):
@@ -88,20 +86,23 @@ class MemcachedTestCase(TestCase):
                 """
                 return key
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
-            self.assertEqual(memcached.get('salt'), 'salt')
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
+            self.assertEqual(memcached.get("salt"), "salt")
 
     # 'set_' function tests: 1
 
     def test_set(self):
-        '''
+        """
         Test if it set a key on the memcached server
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             def __init__(self):
                 self.key = None
                 self.value = None
@@ -113,7 +114,7 @@ class MemcachedTestCase(TestCase):
                 """
                 Mock of stats method
                 """
-                return [('127.0.0.1:11211 (1)', {})]
+                return [("127.0.0.1:11211 (1)", {})]
 
             def set(self, key, value, time, min_compress_len):
                 """
@@ -125,26 +126,35 @@ class MemcachedTestCase(TestCase):
                 self.min_compress_len = min_compress_len
                 return True
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
-            self.assertTrue(memcached.set_('salt', '1111'))
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
+            self.assertTrue(memcached.set_("salt", "1111"))
 
-            self.assertRaises(SaltInvocationError, memcached.set_,
-                              'salt', '1111', time='0.1')
+            self.assertRaises(
+                SaltInvocationError, memcached.set_, "salt", "1111", time="0.1"
+            )
 
-            self.assertRaises(SaltInvocationError, memcached.set_,
-                              'salt', '1111', min_compress_len='0.1')
+            self.assertRaises(
+                SaltInvocationError,
+                memcached.set_,
+                "salt",
+                "1111",
+                min_compress_len="0.1",
+            )
 
     # 'delete' function tests: 1
 
     def test_delete(self):
-        '''
+        """
         Test if it delete a key from memcache server
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             def __init__(self):
                 self.key = None
                 self.time = None
@@ -154,7 +164,7 @@ class MemcachedTestCase(TestCase):
                 """
                 Mock of stats method
                 """
-                return [('127.0.0.1:11211 (1)', {})]
+                return [("127.0.0.1:11211 (1)", {})]
 
             def delete(self, key, time):
                 """
@@ -164,23 +174,27 @@ class MemcachedTestCase(TestCase):
                 self.time = time
                 return True
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
-            self.assertTrue(memcached.delete('salt'))
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
+            self.assertTrue(memcached.delete("salt"))
 
-            self.assertRaises(SaltInvocationError, memcached.delete,
-                              'salt', '1111', time='0.1')
+            self.assertRaises(
+                SaltInvocationError, memcached.delete, "salt", "1111", time="0.1"
+            )
 
     # 'add' function tests: 1
 
     def test_add(self):
-        '''
+        """
         Test if it add a key from memcache server
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             def __init__(self):
                 self.key = None
                 self.value = None
@@ -192,7 +206,7 @@ class MemcachedTestCase(TestCase):
                 """
                 Mock of stats method
                 """
-                return [('127.0.0.1:11211 (1)', {})]
+                return [("127.0.0.1:11211 (1)", {})]
 
             def add(self, key, value, time, min_compress_len):
                 """
@@ -204,26 +218,35 @@ class MemcachedTestCase(TestCase):
                 self.min_compress_len = min_compress_len
                 return True
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
-            self.assertTrue(memcached.add('salt', '1111'))
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
+            self.assertTrue(memcached.add("salt", "1111"))
 
-            self.assertRaises(SaltInvocationError, memcached.add,
-                              'salt', '1111', time='0.1')
+            self.assertRaises(
+                SaltInvocationError, memcached.add, "salt", "1111", time="0.1"
+            )
 
-            self.assertRaises(SaltInvocationError, memcached.add,
-                              'salt', '1111', min_compress_len='0.1')
+            self.assertRaises(
+                SaltInvocationError,
+                memcached.add,
+                "salt",
+                "1111",
+                min_compress_len="0.1",
+            )
 
     # 'replace' function tests: 1
 
     def test_replace(self):
-        '''
+        """
         Test if it replace a key from memcache server
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             def __init__(self):
                 self.key = None
                 self.value = None
@@ -235,7 +258,7 @@ class MemcachedTestCase(TestCase):
                 """
                 Mock of stats method
                 """
-                return [('127.0.0.1:11211 (1)', {})]
+                return [("127.0.0.1:11211 (1)", {})]
 
             def replace(self, key, value, time, min_compress_len):
                 """
@@ -247,26 +270,35 @@ class MemcachedTestCase(TestCase):
                 self.min_compress_len = min_compress_len
                 return True
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
-            self.assertTrue(memcached.replace('salt', '1111'))
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
+            self.assertTrue(memcached.replace("salt", "1111"))
 
-            self.assertRaises(SaltInvocationError, memcached.replace,
-                              'salt', '1111', time='0.1')
+            self.assertRaises(
+                SaltInvocationError, memcached.replace, "salt", "1111", time="0.1"
+            )
 
-            self.assertRaises(SaltInvocationError, memcached.replace,
-                              'salt', '1111', min_compress_len='0.1')
+            self.assertRaises(
+                SaltInvocationError,
+                memcached.replace,
+                "salt",
+                "1111",
+                min_compress_len="0.1",
+            )
 
     # 'increment' function tests: 3
 
     def test_increment(self):
-        '''
+        """
         Test if it increment the value of a key
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             def __init__(self):
                 self.key = None
 
@@ -275,7 +307,7 @@ class MemcachedTestCase(TestCase):
                 """
                 Mock of stats method
                 """
-                return [('127.0.0.1:11211 (1)', {})]
+                return [("127.0.0.1:11211 (1)", {})]
 
             def get(self, key):
                 """
@@ -289,25 +321,29 @@ class MemcachedTestCase(TestCase):
                 Mock of incr method
                 """
                 self.key = key
-                if not isinstance(delta, integer_types):
-                    raise SaltInvocationError('Delta value must be an integer')
+                if not isinstance(delta, int):
+                    raise SaltInvocationError("Delta value must be an integer")
                 return key
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
-            self.assertEqual(memcached.increment('salt'), 'salt')
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
+            self.assertEqual(memcached.increment("salt"), "salt")
 
-            self.assertRaises(SaltInvocationError, memcached.increment,
-                              'salt', delta='sa')
+            self.assertRaises(
+                SaltInvocationError, memcached.increment, "salt", delta="sa"
+            )
 
     def test_increment_exist(self):
-        '''
+        """
         Test if it increment the value of a key
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             def __init__(self):
                 self.key = None
 
@@ -316,7 +352,7 @@ class MemcachedTestCase(TestCase):
                 """
                 Mock of stats method
                 """
-                return [('127.0.0.1:11211 (1)', {})]
+                return [("127.0.0.1:11211 (1)", {})]
 
             def get(self, key):
                 """
@@ -325,19 +361,21 @@ class MemcachedTestCase(TestCase):
                 self.key = key
                 return key
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
-            self.assertRaises(CommandExecutionError, memcached.increment,
-                              'salt')
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
+            self.assertRaises(CommandExecutionError, memcached.increment, "salt")
 
     def test_increment_none(self):
-        '''
+        """
         Test if it increment the value of a key
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             def __init__(self):
                 self.key = None
 
@@ -346,7 +384,7 @@ class MemcachedTestCase(TestCase):
                 """
                 Mock of stats method
                 """
-                return [('127.0.0.1:11211 (1)', {})]
+                return [("127.0.0.1:11211 (1)", {})]
 
             def get(self, key):
                 """
@@ -355,21 +393,23 @@ class MemcachedTestCase(TestCase):
                 self.key = key
                 return None
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
-            self.assertRaises(CommandExecutionError, memcached.increment,
-                              'salt')
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
+            self.assertRaises(CommandExecutionError, memcached.increment, "salt")
 
     # 'decrement' function tests: 3
 
     def test_decrement(self):
-        '''
+        """
         Test if it decrement the value of a key
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             def __init__(self):
                 self.key = None
 
@@ -378,7 +418,7 @@ class MemcachedTestCase(TestCase):
                 """
                 Mock of stats method
                 """
-                return [('127.0.0.1:11211 (1)', {})]
+                return [("127.0.0.1:11211 (1)", {})]
 
             def get(self, key):
                 """
@@ -392,25 +432,29 @@ class MemcachedTestCase(TestCase):
                 Mock of decr method
                 """
                 self.key = key
-                if not isinstance(delta, integer_types):
-                    raise SaltInvocationError('Delta value must be an integer')
+                if not isinstance(delta, int):
+                    raise SaltInvocationError("Delta value must be an integer")
                 return key
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
-            self.assertEqual(memcached.decrement('salt'), 'salt')
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
+            self.assertEqual(memcached.decrement("salt"), "salt")
 
-            self.assertRaises(SaltInvocationError, memcached.decrement,
-                              'salt', delta='sa')
+            self.assertRaises(
+                SaltInvocationError, memcached.decrement, "salt", delta="sa"
+            )
 
     def test_decrement_exist(self):
-        '''
+        """
         Test if it decrement the value of a key
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             def __init__(self):
                 self.key = None
 
@@ -419,7 +463,7 @@ class MemcachedTestCase(TestCase):
                 """
                 Mock of stats method
                 """
-                return [('127.0.0.1:11211 (1)', {})]
+                return [("127.0.0.1:11211 (1)", {})]
 
             def get(self, key):
                 """
@@ -428,19 +472,21 @@ class MemcachedTestCase(TestCase):
                 self.key = key
                 return key
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
-            self.assertRaises(CommandExecutionError, memcached.decrement,
-                              'salt')
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
+            self.assertRaises(CommandExecutionError, memcached.decrement, "salt")
 
     def test_decrement_none(self):
-        '''
+        """
         Test if it decrement the value of a key
-        '''
-        class MockMemcache(object):
+        """
+
+        class MockMemcache:
             """
             Mock of memcache
             """
+
             def __init__(self):
                 self.key = None
 
@@ -449,7 +495,7 @@ class MemcachedTestCase(TestCase):
                 """
                 Mock of stats method
                 """
-                return [('127.0.0.1:11211 (1)', {})]
+                return [("127.0.0.1:11211 (1)", {})]
 
             def get(self, key):
                 """
@@ -458,7 +504,7 @@ class MemcachedTestCase(TestCase):
                 self.key = key
                 return None
 
-        with patch.object(memcached, '_connect',
-                          MagicMock(return_value=MockMemcache())):
-            self.assertRaises(CommandExecutionError, memcached.decrement,
-                              'salt')
+        with patch.object(
+            memcached, "_connect", MagicMock(return_value=MockMemcache())
+        ):
+            self.assertRaises(CommandExecutionError, memcached.decrement, "salt")
